function [Aaxconv]=AxesConv(handles,A)

% This routine performs conversion of derivatives 
% from wind to body axes and vice versa, depending
% on the initial axes notation.
% Source: Cook, 'Flight Dynamics Principles', 1997
%        Appendix 7.
% By Konstantinos Siliverdis 20-Aug-2004
% Corrected by M V Cook March 2013


switch get(handles.mode,'string')
    case 'long'
        if A(27)==1
           Adim=A;
        elseif A(27)== 2
           Adim=norm2dal(A);
        elseif A(27)==3
           Adim=dless2dal(A);
        end;
    case 'lat'
        if A(29)==1
           Adim=A;
        elseif A(29)== 2
           Adim=norm2dal(A);
        elseif A(29)==3
           Adim=dless2dal(A);
        end;
end

switch get(handles.ac_axes,'value')
    case 1 %Wind Axes
        
        switch get(handles.mode,'string')
            case 'long' %Longitudinal case
                
                
%============= Longitudinal Wind to Body Axes ======================
Aaxconv(1:11)=Adim(1:11);
Aaxconv(27:28)=Adim(27:28);
ae=A(4)*pi/180;  % added MVC
% =====  X  ======
Aaxconv(12)=Adim(12)*cos(ae)^2+Adim(18)*sin(ae)^2-(Adim(13)+Adim(17))*cos(ae)*sin(ae);
Aaxconv(13)=Adim(13)*cos(ae)^2-Adim(17)*sin(ae)^2+(Adim(12)-Adim(18))*cos(ae)*sin(ae);
Aaxconv(14)=Adim(14)*cos(ae)^2-Adim(19)*cos(ae)*sin(ae);
Aaxconv(15)=Adim(15)*cos(ae)-Adim(20)*sin(ae);
Aaxconv(16)=Adim(16)*cos(ae)-Adim(21)*sin(ae);
% =====  Z  ======
Aaxconv(17)=Adim(17)*cos(ae)^2-Adim(13)*sin(ae)^2+(Adim(12)-Adim(18))*cos(ae)*sin(ae);
Aaxconv(18)=Adim(18)*cos(ae)^2+Adim(12)*sin(ae)^2+(Adim(13)+Adim(17))*cos(ae)*sin(ae);
Aaxconv(19)=Adim(19)*cos(ae)^2+Adim(14)*cos(ae)*sin(ae);
Aaxconv(20)=Adim(20)*cos(ae)+Adim(15)*sin(ae);
Aaxconv(21)=Adim(21)*cos(ae)+Adim(16)*sin(ae);
% =====  M  ======
Aaxconv(22)=Adim(22)*cos(ae)-Adim(23)*sin(ae);
Aaxconv(23)=Adim(23)*cos(ae)+Adim(22)*sin(ae);
Aaxconv(24)=Adim(24)*cos(ae);
Aaxconv(25)=Adim(25);
Aaxconv(26)=Adim(26);
Aaxconv(27:28)=Adim(27:28);

            case 'lat' %Lateral-Directional Case
                
   
%=============== Lateral-Directional Wind to Body Axes ====================
Aaxconv(1:13)=Adim(1:13);
Aaxconv(29:30)=Adim(29:30);
ae=A(4)*pi/180;  % added MVC
% =====  Y  ======
Aaxconv(14)=Adim(14);
Aaxconv(15)=Adim(15)*cos(ae)-Adim(16)*sin(ae);
Aaxconv(16)=Adim(16)*cos(ae)+Adim(15)*sin(ae);
Aaxconv(17)=Adim(17);
Aaxconv(18)=Adim(18);
% =====  L  ======
Aaxconv(19)=Adim(19)*cos(ae)-Adim(24)*sin(ae);
Aaxconv(20)=Adim(20)*cos(ae)^2+Adim(26)*sin(ae)^2-(Adim(21)+Adim(25))*cos(ae)*sin(ae);
Aaxconv(21)=Adim(21)*cos(ae)^2-Adim(25)*sin(ae)^2+(Adim(20)-Adim(26))*cos(ae)*sin(ae);
Aaxconv(23)=Adim(23)*cos(ae)-Adim(28)*sin(ae);
% =====  N  ======
Aaxconv(24)=Adim(24)*cos(ae)+Adim(19)*sin(ae);
Aaxconv(25)=Adim(25)*cos(ae)^2+Adim(20)*sin(ae)^2+(Adim(21)+Adim(25))*cos(ae)*sin(ae);
Aaxconv(27)=Adim(27)*cos(ae)+Adim(22)*sin(ae);
Aaxconv(28)=Adim(28)*cos(ae)+Adim(23)*sin(ae);

            end  %of wind axes notation
  
            
    case 2  %Body Axes
        
        switch get(handles.mode,'string')
            case 'long'  %Longitudinal case
                

%============= Longitudinal Body to Wind Axes =============================
Aaxconv(1:11)=Adim(1:11);
Aaxconv(27:28)=Adim(27:28);
ae=A(4)*pi/180;% MVC
% =====  X  ======
Aaxconv(12)=Adim(12)*cos(ae)*cos(ae)+Adim(18)*sin(ae)*sin(ae)+(Adim(13)+Adim(17))*cos(ae)*sin(ae);
Aaxconv(13)=Adim(13)*cos(ae)*cos(ae)-Adim(17)*sin(ae)*sin(ae)-(Adim(12)-Adim(18))*cos(ae)*sin(ae);
Aaxconv(14)=Adim(14)*cos(ae)*cos(ae)+Adim(19)*cos(ae)*sin(ae);
Aaxconv(15)=Adim(15)*cos(ae)+Adim(20)*sin(ae);
Aaxconv(16)=Adim(16)*cos(ae)+Adim(21)*sin(ae);
% =====  Z  ======
Aaxconv(17)=Adim(17)*cos(ae)*cos(ae)-Adim(13)*sin(ae)*sin(ae)-(Adim(12)-Adim(18))*cos(ae)*sin(ae);
Aaxconv(18)=Adim(18)*cos(ae)*cos(ae)+Adim(12)*sin(ae)*sin(ae)-(Adim(13)+Adim(17))*cos(ae)*sin(ae);
Aaxconv(19)=Adim(19)*cos(ae)*cos(ae)-Adim(14)*cos(ae)*sin(ae);
Aaxconv(20)=Adim(20)*cos(ae)-Adim(15)*sin(ae);
Aaxconv(21)=Adim(21)*cos(ae)-Adim(16)*sin(ae);
% =====  M  ======
Aaxconv(22)=Adim(22)*cos(ae)+Adim(23)*sin(ae);
Aaxconv(23)=Adim(23)*cos(ae)-Adim(22)*sin(ae);
Aaxconv(24)=Adim(24)*cos(ae);
Aaxconv(25)=Adim(25);
Aaxconv(26)=Adim(26);


            case 'lat'  %Lateral-Directional case
                
                
%=========== Lateral-Directional Body to Wind Axes ========================
Aaxconv(1:13)=Adim(1:13);
Aaxconv(29:30)=Adim(29:30);
ae=A(4)*pi/180;% MVC
% =====  Y  ======
Aaxconv(14)=Adim(14);
Aaxconv(15)=Adim(15)*cos(ae)+Adim(16)*sin(ae);
Aaxconv(16)=Adim(16)*cos(ae)-Adim(15)*sin(ae);
Aaxconv(17)=Adim(17);
Aaxconv(18)=Adim(18);
% =====  L  ======
Aaxconv(19)=Adim(19)*cos(ae)+Adim(24)*sin(ae);
Aaxconv(20)=Adim(20)*cos(ae)^2+Adim(26)*sin(ae)^2+(Adim(21)+Adim(25))*cos(ae)*sin(ae);
Aaxconv(21)=Adim(21)*cos(ae)^2-Adim(25)*sin(ae)^2-(Adim(20)-Adim(26))*cos(ae)*sin(ae);
Aaxconv(22)=Adim(22)*cos(ae)+Adim(27)*sin(ae);
Aaxconv(23)=Adim(23)*cos(ae)+Adim(28)*sin(ae);
% =====  N  ======
Aaxconv(24)=Adim(24)*cos(ae)-Adim(19)*sin(ae);
Aaxconv(25)=Adim(25)*cos(ae)^2-Adim(21)*sin(ae)^2-(Adim(20)-Adim(26))*cos(ae)*sin(ae);
Aaxconv(26)=Adim(26)*cos(ae)^2+Adim(20)*sin(ae)^2-(Adim(21)+Adim(25))*cos(ae)*sin(ae)
Aaxconv(28)=Adim(28)*cos(ae)-Adim(23)*sin(ae);

            end %of body axes notation
            
end
    
    


        