function CompareLatplot(handles);

% This function plots the Lateral/Directional time histories for the 2
% saved Lateral/Directional analysis. 
% By Konstantinos Siliverdis 20-Aug-2004
% Modified by M V Cook January 2013

%Check if the two SavePlot buttons are toggled
H=findobj([handles.SavePlot1,handles.SavePlot2],'value',1);
if length(H)~=2
    errordlg('Both ''Save Plot'' buttons must be toggled',...
             'error','modal')
else        

if isstr(get(handles.filename,'String'))
    FigureTitle = get(handles.filename,'String');
else
    FigureTitle = cell2mat(get(handles.filename,'String'));
end
clc
[fig flag]=figflag('Time Histories');
if fig == 1
    close(flag)

end


[TimeVector,InputVector]=GetTimeVector(handles);
switch get(handles.latordir,'value')
    case 1 %Lateral
% Retrieve saved plot 1 data
PLOT1=getappdata(handles.SavePlot1,'PLOT1');
NUMA=PLOT1{1};
DEN=PLOT1{3};
SYSbetaA1=tf(NUMA( 1,:),DEN,'inputname','Fs','outputname','\beta - Sideslip angle');
SYSpA1   =tf(NUMA( 2,:),DEN,'inputname','Fs','outputname','p - Roll rate');
SYSrA1   =tf(NUMA( 3,:),DEN,'inputname','Fs','outputname','r - Yaw rate');
SYSphiA1 =tf(NUMA( 4,:),DEN,'inputname','Fs','outputname','\phi - Roll attitude');
% Retrieve saved plot 2 data
PLOT2=getappdata(handles.SavePlot2,'PLOT2');
NUMA=PLOT2{1};
DEN=PLOT2{3};
SYSbetaA2=tf(NUMA( 1,:),DEN,'inputname','Fs','outputname','\beta - Sideslip angle');
SYSpA2   =tf(NUMA( 2,:),DEN,'inputname','Fs','outputname','p - Roll rate');
SYSrA2   =tf(NUMA( 3,:),DEN,'inputname','Fs','outputname','r - Yaw rate');
SYSphiA2 =tf(NUMA( 4,:),DEN,'inputname','Fs','outputname','\phi - Roll attitude');

    case 2 %Directional
% Retrieve saved plot 1 data
PLOT1=getappdata(handles.SavePlot1,'PLOT1');
NUMR=PLOT1{2};
DEN=PLOT1{3};
SYSbetaR1=tf(NUMR( 1,:),DEN,'inputname','Fs','outputname','\beta - Sideslip angle');
SYSpR1   =tf(NUMR( 2,:),DEN,'inputname','Fs','outputname','p - Roll rate');
SYSrR1   =tf(NUMR( 3,:),DEN,'inputname','Fs','outputname','r - Yaw rate');
SYSphiR1 =tf(NUMR( 4,:),DEN,'inputname','Fs','outputname','\phi - Roll attitude');
% Retrieve saved plot 2 data
PLOT2=getappdata(handles.SavePlot2,'PLOT2');
NUMR=PLOT2{2};
DEN=PLOT2{3};
SYSbetaR2=tf(NUMR( 1,:),DEN,'inputname','Fs','outputname','\beta - Sideslip angle');
SYSpR2   =tf(NUMR( 2,:),DEN,'inputname','Fs','outputname','p - Roll rate');
SYSrR2   =tf(NUMR( 3,:),DEN,'inputname','Fs','outputname','r - Yaw rate');
SYSphiR2 =tf(NUMR( 4,:),DEN,'inputname','Fs','outputname','\phi - Roll attitude');
end
PlotTime = str2double(get(handles.PlotTime, 'String'));
t = 0:PlotTime/1000:PlotTime; 

p(1) = get(handles.beta_ail_ch, 'Value');
p(2) = get(handles.p_ail_ch, 'Value');
p(3) = get(handles.r_ail_ch, 'Value');
p(4) = get(handles.phi_ail_ch, 'Value');
p(5) = get(handles.beta_r_ch, 'Value');
p(6) = get(handles.p_r_ch, 'Value');
p(7) = get(handles.r_r_ch, 'Value');
p(8) = get(handles.phi_r_ch, 'Value');

totalplots = p(1)+p(2)+p(3)+p(4)+p(5)+p(6)+p(7)+p(8);
switch totalplots
    case {1,2,3,4}
        plotsacross    =   1;
        plotsdown      =   totalplots;
    case {5,6}
        plotsacross    =   2;
        plotsdown      =   3;
    case {7,8}
        plotsacross    =   2;
        plotsdown      =   4;
end
plotted = 1; % counter for which plot number we are up to

    switch get(handles.inputsignal,'Value')
        case 1  %   Step 
            inputsignal = 'Step Input';
        case 2  %   Impulse 
            inputsignal = 'Impulse Input';
        case 3  %   Pulse
            inputsignal = 'Pulse Input';
        case 4  %   Ramp
            inputsignal = 'Ramp Input';
        case 5  %   Sine
            inputsignal = 'Sine Input';
        case 6  %   Doublet
            inputsignal = 'Doublet Input';
    end

h = waitbar(0,'Even harder sums - please wait...','Position',[460 250 270 56],'name','Plot Comparison in Progress');
%waitbar(0)
%set(h,'Visible','on')

figure(500)
set(500,'Position',[5    35   600   685],'Name','Time Histories','NumberTitle','off');
%set(fdacad,'Pointer','watch');
%figure(500)
if p(1)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSbetaA2,'b',InputVector,TimeVector);
    lsim(SYSbetaA2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSbetaA1,'b',InputVector,TimeVector);
    lsim(SYSbetaA1,'r:',InputVector,TimeVector)
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    hold off
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Aileron Command','FontSize',8)
    plotted = plotted + 1;
    legend('Plot 2','Plot 1',0)
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(2)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSpA2,'b',InputVector,TimeVector);
    lsim(SYSpA2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSpA1,'b',InputVector,TimeVector);
    lsim(SYSpA1,'r:',InputVector,TimeVector)
    hold off
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Aileron Command','FontSize',8)
    plotted = plotted + 1;
    legend('Plot 2','Plot 1',0)
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(3)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSrA2,'b',InputVector,TimeVector);
    lsim(SYSrA2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSrA1,'r:',InputVector,TimeVector);
    lsim(SYSrA1,'r:',InputVector,TimeVector)
    hold off
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Aileron Command','FontSize',8)
    plotted = plotted + 1;
    legend('Plot 2','Plot 1',0)
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(4)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSphiA2,'b',InputVector,TimeVector);
    lsim(SYSphiA2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSphiA1,'r:',InputVector,TimeVector);
    lsim(SYSphiA1,'r:',InputVector,TimeVector)
    hold off
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Aileron Command','FontSize',8)
    plotted = plotted + 1;
    legend('Plot 2','Plot 1',0)
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(5)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSbetaR2,'b',InputVector,TimeVector);
    lsim(SYSbetaR2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSbetaR1,'r:',InputVector,TimeVector);
    lsim(SYSbetaR1,'r:',InputVector,TimeVector)
    hold off
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Rudder Command','FontSize',8)
    plotted = plotted + 1;
    legend('Plot 2','Plot 1',0)
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(6)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSpR2,'b',InputVector,TimeVector);
    lsim(SYSpR2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSpR1,'r:',InputVector,TimeVector);
    lsim(SYSpR1,'r:',InputVector,TimeVector)
    hold off
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Rudder Command','FontSize',8)
    plotted = plotted + 1;
    legend('Plot 2','Plot 1',0)
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(7)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSrR2,'b',InputVector,TimeVector);
    lsim(SYSrR2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSrR1,'b',InputVector,TimeVector);
    lsim(SYSrR1,'r:',InputVector,TimeVector)
    hold off
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Rudder Command','FontSize',8)
    plotted = plotted + 1;
    legend('Plot 2','Plot 1',0)
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(8)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSphiR2,'b',InputVector,TimeVector);
    lsim(SYSphiR2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSphiR1,'b',InputVector,TimeVector);
    lsim(SYSphiR1,'r:',InputVector,TimeVector)
    hold off
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Rudder Command','FontSize',8)
    plotted = plotted + 1;
    legend('Plot 2','Plot 1',0)
end
hold

t=subplot(1000000,1,1);set(t,'color','none','Xcolor',[.8 .8 .8], 'Ycolor', [.8 .8 .8])
title(FigureTitle , 'Fontsize', 14)
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%set(fdacad,'Pointer','custom');
figure(500);
waitbar(1)
close(h)
end
return
clc;