function CompareLongPlot (handles)

% This function plots the Longitudinal time histories for the 2 saved
% plots.
% By Konstantinos Siliverdis 20-Aug-2004
% Modfied by M V Cook January2013

%Check if the two SavePlot buttons are toggled
H=findobj([handles.SavePlot1,handles.SavePlot2],'value',1);
if length(H)~=2
    errordlg('Both ''Save Plot'' buttons must be toggled',...
             'error','modal')
else        

% FigureTitle = get(handles.FigureTitle, 'String');
if isstr(get(handles.filename,'String'))
    FigureTitle = get(handles.filename,'String');
else
    FigureTitle = cell2mat(get(handles.filename,'String'));
end
clc
[fig flag]=figflag('Time Histories');
if fig == 1
    close(flag)
end


[TimeVector,InputVector]=GetTimeVector(handles);
% Retrieve saved plot 1 data
PLOT1=getappdata(handles.SavePlot1,'PLOT1')
NUM=PLOT1{1};
DEN=PLOT1{2};
SYSu1    =tf(NUM( 1,:),DEN,'inputname','Fs','outputname','u - Axial velocity');
SYSw1    =tf(NUM( 2,:),DEN,'inputname','Fs','outputname','w - Normal velocity');
SYSq1    =tf(NUM( 3,:),DEN,'inputname','Fs','outputname','q - Pitch rate');
SYStheta1=tf(NUM( 4,:),DEN,'inputname','Fs','outputname','\theta - Pitch attitude');
SYSaz1   =tf(NUM( 5,:),DEN,'inputname','Fs','outputname','Az - Normal acceleration');
SYSalpha1=tf(NUM( 6,:),DEN,'inputname','Fs','outputname','\alpha - Angle of attack');
SYSgamma1=tf(NUM( 7,:),DEN,'inputname','Fs','outputname','\gamma - Flight path angle');
SYSh1    =tf(NUM( 8,:),DEN,'inputname','Fs','outputname','h - height');

% Retrieve saved plot 2 data
PLOT2=getappdata(handles.SavePlot2,'PLOT2');
NUM=PLOT2{1};
DEN=PLOT2{2};
SYSu2    =tf(NUM( 1,:),DEN,'inputname','Fs','outputname','u - Axial velocity');
SYSw2    =tf(NUM( 2,:),DEN,'inputname','Fs','outputname','w - Normal velocity');
SYSq2    =tf(NUM( 3,:),DEN,'inputname','Fs','outputname','q - Pitch rate');
SYStheta2=tf(NUM( 4,:),DEN,'inputname','Fs','outputname','\theta - Pitch attitude');
SYSaz2   =tf(NUM( 5,:),DEN,'inputname','Fs','outputname','Az - Normal acceleration');
SYSalpha2=tf(NUM( 6,:),DEN,'inputname','Fs','outputname','\alpha - Angle of attack');
SYSgamma2=tf(NUM( 7,:),DEN,'inputname','Fs','outputname','\gamma - Flight path angle');
SYSh2    =tf(NUM( 8,:),DEN,'inputname','Fs','outputname','h - height');

PlotTime = str2double(get(handles.PlotTime, 'String'));
t = 0:PlotTime/1000:PlotTime; 

p(1) = get(handles.u_lon_ch, 'Value');
p(2) = get(handles.w_lon_ch, 'Value');
p(3) = get(handles.q_lon_ch, 'Value');
p(4) = get(handles.theta_lon_ch, 'Value');
p(5) = get(handles.az_lon_ch, 'Value');
p(6) = get(handles.a_lon_ch, 'Value');
p(7) = get(handles.gamma_lon_ch, 'Value');
p(8) = get(handles.h_lon_ch, 'Value');

totalplots = p(1)+p(2)+p(3)+p(4)+p(5)+p(6)+p(7)+p(8);
switch totalplots
    case {1,2,3,4}
        plotsacross    =   1;
        plotsdown      =   totalplots;
    %case 4
    %    plotsacross    =   2;
    %    plotsdown      =   2;        
    case {5,6}
        plotsacross    =   2;
        plotsdown      =   3;
    case {7,8}
        plotsacross    =   2;
        plotsdown      =   4;
end
plotted = 1; % Sets initial value for plot counter

    switch get(handles.inputsignal,'Value')
        case 1  %   Step 
            inputsignal = 'Step Input';
        case 2  %   Impulse 
            inputsignal = 'Impulse Input';
        case 3  %   Pulse
            inputsignal = 'Pulse Input';
        case 4  %   Ramp
            inputsignal = 'Ramp Input';
        case 5  %   Sine
            inputsignal = 'Sine Input';
        case 6  %   Doublet
            inputsignal = 'Doublet Input';
    end
    
h = waitbar(0,'Even harder sums - please wait...','Position',[460 250 270 56],'name','Plot Comparison in Progress');
%waitbar(0)
%set(h,'Visible','on')

figure(500)
set(500,'Position',[5   35   600   685],'Name','Time Histories','NumberTitle','off');

%figure(500)
if p(1)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSu2,'b',InputVector,TimeVector);
    lsim(SYSu2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSu1,'r:',InputVector,TimeVector);
    lsim(SYSu1,'r:',InputVector,TimeVector),legend('Plot 2','Plot 1',0)
    hold off
    grid on, box on
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    title (inputsignal,'FontSize',8)
    ylabel ('Elevator Command','FontSize',8)
    plotted = plotted + 1;
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(2)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSw2,'b',InputVector,TimeVector);
    lsim(SYSw2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSw1,'b',InputVector,TimeVector);
    lsim(SYSw1,'r:',InputVector,TimeVector),legend('Plot 2','Plot 1',0)
    hold off
    grid on, box on
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    title (inputsignal,'FontSize',8)
    ylabel ('Elevator Command','FontSize',8)
    plotted = plotted + 1;
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(3)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSq2,'b',InputVector,TimeVector);
    lsim(SYSq2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSq1,'r:',InputVector,TimeVector);
    lsim(SYSq1,'r:',InputVector,TimeVector),legend('Plot 2','Plot 1',0)
    hold off
    grid on, box on
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    title (inputsignal,'FontSize',8)
    ylabel ('Elevator Command','FontSize',8)
    plotted = plotted + 1;
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(4)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYStheta2,'b',InputVector,TimeVector);
    lsim(SYStheta2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYStheta1,'r:',InputVector,TimeVector);
    lsim(SYStheta1,'r:',InputVector,TimeVector),legend('Plot 2','Plot 1',0)
    hold off
    grid on, box on
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    title (inputsignal,'FontSize',8)
    ylabel ('Elevator Command','FontSize',8)
    plotted = plotted + 1;
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(5)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSaz2,'b',InputVector,TimeVector);
    lsim(SYSaz2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSaz1,'r:',InputVector,TimeVector);
    lsim(SYSaz1,'r:',InputVector,TimeVector),legend('Plot 2','Plot 1',0)
    hold off
    grid on, box on
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    title (inputsignal,'FontSize',8)
    ylabel ('Elevator Command','FontSize',8)
    plotted = plotted + 1;
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(6)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSalpha2,'b',InputVector,TimeVector);
    lsim(SYSalpha2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSalpha1,'r:',InputVector,TimeVector);
    lsim(SYSalpha1,'r:',InputVector,TimeVector),legend('Plot 2','Plot 1',0)
    hold off
    grid on, box on
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    title (inputsignal,'FontSize',8)
    ylabel ('Elevator Command','FontSize',8)
    plotted = plotted + 1;
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(7)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSgamma2,'b',InputVector,TimeVector);
    lsim(SYSgamma2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSgamma1,'r:',InputVector,TimeVector);
    lsim(SYSgamma1,'r:',InputVector,TimeVector),legend('Plot 2','Plot 1',0)
    hold off
    grid on, box on
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    title (inputsignal,'FontSize',8)
    ylabel ('Elevator Command','FontSize',8)
    plotted = plotted + 1;
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500);
if p(8)
    subplot(plotsdown,plotsacross,plotted)
    [x2 y2]=lsim(SYSh2,'b',InputVector,TimeVector);
    lsim(SYSh2,'b',InputVector,TimeVector)
    hold
    [x1 y1]=lsim(SYSh1,'r:',InputVector,TimeVector);
    lsim(SYSh1,'r:',InputVector,TimeVector),legend('Plot 2','Plot 1',0)
    hold off
    grid on, box on
    axis([min(min(y1),min(y2)), max(max(y1),max(y2)), min(min(x1),min(x2)), max(max(x1),max(x2))])
    title (inputsignal,'FontSize',8)
    ylabel ('Elevator Command','FontSize',8)
    plotted = plotted + 1;
end
hold

t=subplot(1000000,1,1);set(t,'color','none','Xcolor',[.8 .8 .8], 'Ycolor', [.8 .8 .8])
title(FigureTitle , 'Fontsize', 14)
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%set(fdacad,'Pointer','custom');
figure(500);
waitbar(1)
close(h)
end
return 
clc;
   
