function DerivReport(handles,Aconv,form,ax)

% This function prints a report in the workspace
% containing the original and the converted derivatives
% together with the height, speed and angle of attack conditions
% By Konstantinos Siliverdis 20-Aug-2004

clc

% Original format
val=get(handles.DerivativeFormat,'value');
switch val
    case 1
        derform='Dimensional';
    case 2
        derform='Normalised [USA]';
    case 3
        derform='Dimensionless [UK]';
end        
        
if length(get(handles.filename,'String')) > 0
    filenamestring = get(handles.filename,'String');
else
    filenamestring = '*.mat';
end

%Desired format
if form==1
    desform='Dimensional';
elseif form==2
    desform='Normalised [USA]';
elseif form==3
    desform='Dimensionless [UK]';
end

if ax==1
    desax='Wind Axes';
elseif ax==2
    desax='Body Axes';
end

A=geta(handles);


switch get(handles.mode,'string')
    case 'long'
        
        switch get(handles.ac_axes,'Value');
            case 1
    
    disp('=======================================================')            
    disp(sprintf('DERIVATIVE CONVERSION REPORT FOR: %s',filenamestring))             
    disp('=======================================================')
    disp(' ')
    disp(sprintf('General Flight Conditions: \nMach: %2.2f \nHeight: %d ft \nBody Incidence: %2.2f deg',A(1),A(2),A(4)));  
    disp(' ')
    disp('Original Axes notation: WIND AXES')
    disp(' ')
    disp(' ')
    disp(sprintf('=======%s Derivatives in Wind Axes=======',derform))
    disp(' ')
    disp(sprintf('  Xu=%15.5f           Zu=%15.5f         Mu=%15.5f',A(12),A(17),A(22)))
    disp(sprintf('  Xw=%15.5f           Zw=%15.5f         Mw=%15.5f',A(13),A(18),A(23)))
    disp(sprintf(' Xdw=%15.5f          Zdw=%15.5f        Mdw=%15.5f',A(14),A(19),A(24)))
    disp(sprintf('  Xq=%15.5f           Zq=%15.5f         Mq=%15.5f',A(15),A(20),A(25)))
    disp(sprintf('Xeta=%15.5f         Zeta=%15.5f       Meta=%15.5f',A(16),A(21),A(26)))
    disp(' ')
    disp(' ')
    disp(' ')
    disp(sprintf('=======%s Derivatives in %s=======',desform,desax))
    disp(' ')
    disp(sprintf('  Xu=%15.5f           Zu=%15.5f         Mu=%15.5f',Aconv(12),Aconv(17),Aconv(22)))
    disp(sprintf('  Xw=%15.5f           Zw=%15.5f         Mw=%15.5f',Aconv(13),Aconv(18),Aconv(23)))
    disp(sprintf(' Xdw=%15.5f          Zdw=%15.5f        Mdw=%15.5f',Aconv(14),Aconv(19),Aconv(24)))
    disp(sprintf('  Xq=%15.5f           Zq=%15.5f         Mq=%15.5f',Aconv(15),Aconv(20),Aconv(25)))
    disp(sprintf('Xeta=%15.5f         Zeta=%15.5f       Meta=%15.5f',Aconv(16),Aconv(21),Aconv(26)))
    disp(' ')
    disp(' ')
    disp(' ')
    
            case 2
    
    disp('=======================================================')            
    disp(sprintf('DERIVATIVE CONVERSION REPORT FOR: %s',filenamestring))             
    disp('=======================================================')
    disp(' ')
    disp(sprintf('General Flight Conditions: \nMach: %2.2f \nHeight: %d ft \nBody Incidence: %2.2f deg',A(1),A(2),A(4)));
    disp(' ')
    disp('Original Axes notation: BODY AXES')
    disp(' ')
    disp(' ')
    disp(sprintf('=======%s Derivatives in Body Axes=======',derform))
    disp(' ')
    disp(sprintf('  Xu=%15.5f           Zu=%15.5f         Mu=%15.5f',A(12),A(17),A(22)))
    disp(sprintf('  Xw=%15.5f           Zw=%15.5f         Mw=%15.5f',A(13),A(18),A(23)))
    disp(sprintf(' Xdw=%15.5f          Zdw=%15.5f        Mdw=%15.5f',A(14),A(19),A(24)))
    disp(sprintf('  Xq=%15.5f           Zq=%15.5f         Mq=%15.5f',A(15),A(20),A(25)))
    disp(sprintf('Xeta=%15.5f         Zeta=%15.5f       Meta=%15.5f',A(16),A(21),A(26)))
    disp(' ')
    disp(' ')
    disp(' ')
    disp(sprintf('=======%s Derivatives in %s=======',desform,desax))
    disp(' ')
    disp(sprintf('  Xu=%15.5f           Zu=%15.5f         Mu=%15.5f',Aconv(12),Aconv(17),Aconv(22)))
    disp(sprintf('  Xw=%15.5f           Zw=%15.5f         Mw=%15.5f',Aconv(13),Aconv(18),Aconv(23)))
    disp(sprintf(' Xdw=%15.5f          Zdw=%15.5f        Mdw=%15.5f',Aconv(14),Aconv(19),Aconv(24)))
    disp(sprintf('  Xq=%15.5f           Zq=%15.5f         Mq=%15.5f',Aconv(15),Aconv(20),Aconv(25)))
    disp(sprintf('Xeta=%15.5f         Zeta=%15.5f       Meta=%15.5f',Aconv(16),Aconv(21),Aconv(26)))
    disp(' ')
    disp(' ')
    disp(' ')
    
            end
            
    case 'lat'
        
        switch get(handles.ac_axes,'Value');
            case 1
                
    disp('=======================================================')            
    disp(sprintf('DERIVATIVE CONVERSION REPORT FOR: %s',filenamestring))             
    disp('=======================================================')
    disp(' ')
    disp(sprintf('General Flight Conditions: \nMach: %2.2f \nHeight: %d ft \nBody Incidence: %2.2f deg',A(1),A(2),A(4)));
    disp(' ')
    disp('Original Axes notation: WIND AXES')
    disp(' ')
    disp(' ')
    
    if val==2;
    disp(sprintf('=======%s Derivatives in Wind Axes=======',derform))
    disp('===== Modified Normalised derivatives - see FDP eqn:4.84 =====')
    disp(' ')
    disp(sprintf('   Yv=%15.5f        Lbeta=%15.5f      Nbeta=%15.5f',A(14),A(19),A(24)))
    disp(sprintf('   Yp=%15.5f           Lp=%15.5f         Np=%15.5f',A(15),A(20),A(25)))
    disp(sprintf('   Yr=%15.5f           Lr=%15.5f         Nr=%15.5f',A(16),A(21),A(26)))
    disp(sprintf(' Y*da=%15.5f          Lda=%15.5f        Nda=%15.5f',A(17),A(22),A(27)))
    disp(sprintf(' Y*dr=%15.5f          Ldr=%15.5f        Ndr=%15.5f',A(18),A(23),A(28)))    
    else
    disp(sprintf('=======%s Derivatives in Wind Axes=======',derform))
    disp(' ')
    disp(sprintf('   Yv=%15.5f           Lv=%15.5f         Nv=%15.5f',A(14),A(19),A(24)))
    disp(sprintf('   Yp=%15.5f           Lp=%15.5f         Np=%15.5f',A(15),A(20),A(25)))
    disp(sprintf('   Yr=%15.5f           Lr=%15.5f         Nr=%15.5f',A(16),A(21),A(26)))
    disp(sprintf('  Yxi=%15.5f          Lxi=%15.5f        Nxi=%15.5f',A(17),A(22),A(27)))
    disp(sprintf('Yzeta=%15.5f         Lzeta=%15.5f     Nzeta=%15.5f',A(18),A(23),A(28)))
    end
    disp(' ')
    disp(' ')
    disp(' ')
    if form==2;
    disp(sprintf('=======%s Derivatives in %s=======',desform,desax))
    disp('===== Modified Normalised derivatives - see FDP eqn:4.84 =====')
    disp(' ')
    disp(sprintf('   Yv=%15.5f        Lbeta=%15.5f      Nbeta=%15.5f',Aconv(14),Aconv(19),Aconv(24)))
    disp(sprintf('   Yp=%15.5f           Lp=%15.5f         Np=%15.5f',Aconv(15),Aconv(20),Aconv(25)))
    disp(sprintf('   Yr=%15.5f           Lr=%15.5f         Nr=%15.5f',Aconv(16),Aconv(21),Aconv(26)))
    disp(sprintf('  Y*da=%15.5f          Lda=%15.5f        Nda=%15.5f',Aconv(17),Aconv(22),Aconv(27)))
    disp(sprintf('  Y*dr=%15.5f          Ldr=%15.5f        Ndr=%15.5f',Aconv(18),Aconv(23),Aconv(28)))
    else
    disp(sprintf('=======%s Derivatives in %s=======',desform,desax))
    disp(' ')
    disp(sprintf('   Yv=%15.5f           Lv=%15.5f         Nv=%15.5f',Aconv(14),Aconv(19),Aconv(24)))
    disp(sprintf('   Yp=%15.5f           Lp=%15.5f         Np=%15.5f',Aconv(15),Aconv(20),Aconv(25)))
    disp(sprintf('   Yr=%15.5f           Lr=%15.5f         Nr=%15.5f',Aconv(16),Aconv(21),Aconv(26)))
    disp(sprintf('  Yxi=%15.5f          Lxi=%15.5f        Nxi=%15.5f',Aconv(17),Aconv(22),Aconv(27)))
    disp(sprintf('Yzeta=%15.5f        Lzeta=%15.5f      Nzeta=%15.5f',Aconv(18),Aconv(23),Aconv(28)))
    end 
    disp(' ')
    disp(' ')
    disp(' ')
    
            case 2
                
    disp('=======================================================')            
    disp(sprintf('DERIVATIVE CONVERSION REPORT FOR: %s',filenamestring))             
    disp('=======================================================')
    disp(' ')
    disp(' ')
    disp('Original Axes notation: BODY AXES')
    disp(' ')
    disp(sprintf('General Flight Conditions: \nMach: %2.2f \nHeight: %d ft \nBody Incidence: %2.2f deg',A(1),A(2),A(4)));
    disp(' ')
    if val==2; 
    disp(sprintf('=======%s Derivatives in Body Axes=======',derform))
    disp('===== Modified Normalised derivatives - see FDP eqn:4.84 =====')
    disp(' ')
    disp(sprintf('   Yv=%15.5f        Lbeta=%15.5f      Nbeta=%15.5f',A(14),A(19),A(24)))
    disp(sprintf('   Yp=%15.5f           Lp=%15.5f         Np=%15.5f',A(15),A(20),A(25)))
    disp(sprintf('   Yr=%15.5f           Lr=%15.5f         Nr=%15.5f',A(16),A(21),A(26)))
    disp(sprintf(' Y*da=%15.5f          Lda=%15.5f        Nda=%15.5f',A(17),A(22),A(27)))
    disp(sprintf(' Y*dr=%15.5f          Ldr=%15.5f        Ndr=%15.5f',A(18),A(23),A(28)))
    else
       disp(sprintf('=======%s Derivatives in Body Axes=======',derform))
    disp(' ')
    disp(sprintf('   Yv=%15.5f           Lv=%15.5f         Nv=%15.5f',A(14),A(19),A(24)))
    disp(sprintf('   Yp=%15.5f           Lp=%15.5f         Np=%15.5f',A(15),A(20),A(25)))
    disp(sprintf('   Yr=%15.5f           Lr=%15.5f         Nr=%15.5f',A(16),A(21),A(26)))
    disp(sprintf('  Yxi=%15.5f          Lxi=%15.5f        Nxi=%15.5f',A(17),A(22),A(27)))
    disp(sprintf('Yzeta=%15.5f        Lzeta=%15.5f      Nzeta=%15.5f',A(18),A(23),A(28)))
    end
    disp(' ')
    disp(' ')
    disp(' ')
    if form==2;
    disp(sprintf('=======%s Derivatives in %s=======',desform,desax))
    disp('===== Modified Normalised derivatives - see FDP eqn:4.84 =====')
    disp(' ')
    disp(sprintf('   Yv=%15.5f        Lbeta=%15.5f      Nbeta=%15.5f',Aconv(14),Aconv(19),Aconv(24)))
    disp(sprintf('   Yp=%15.5f           Lp=%15.5f         Np=%15.5f',Aconv(15),Aconv(20),Aconv(25)))
    disp(sprintf('   Yr=%15.5f           Lr=%15.5f         Nr=%15.5f',Aconv(16),Aconv(21),Aconv(26)))
    disp(sprintf(' Y*da=%15.5f          Lda=%15.5f        Nda=%15.5f',Aconv(17),Aconv(22),Aconv(27)))
    disp(sprintf(' Y*dr=%15.5f          Ldr=%15.5f        Ndr=%15.5f',Aconv(18),Aconv(23),Aconv(28)))
    disp(' ')
    disp(' ')
    disp(' ')
    else
    disp(sprintf('=======%s Derivatives in %s=======',desform,desax))
    disp(' ')
    disp(sprintf('   Yv=%15.5f           Lv=%15.5f         Nv=%15.5f',Aconv(14),Aconv(19),Aconv(24)))
    disp(sprintf('   Yp=%15.5f           Lp=%15.5f         Np=%15.5f',Aconv(15),Aconv(20),Aconv(25)))
    disp(sprintf('   Yr=%15.5f           Lr=%15.5f         Nr=%15.5f',Aconv(16),Aconv(21),Aconv(26)))
    disp(sprintf('  Yxi=%15.5f          Lxi=%15.5f        Nxi=%15.5f',Aconv(17),Aconv(22),Aconv(27)))
    disp(sprintf('Yzeta=%15.5f        Lzeta=%15.5f      Nzeta=%15.5f',Aconv(18),Aconv(23),Aconv(28)))
    disp(' ')
    disp(' ')
    disp(' ')
    end
    
            end
            
end

msgbox(sprintf('A Derivative Conversion Report was generated\nin the Matlab command window. If you wish to\nobtain a hard copy select File - Print, from\nthe Matlab Command Window menu.'),'Report generated','help');
