function [ TimeVector,InputVector ] = GetTimeVector(handles)
% Returns the time & input vectors based on 'Input' selection and 'Plot
% response time' selection. This function is called by the time history
% plotting functions. Originally developed by Rees 2003. 

 time = str2double(get(handles.PlotTime,'String'));
 plotpoints = 10000;%get(handles.plotpoints,'Value');
 TimeVector = 0:time/plotpoints:time;
 amplitude = str2double(get(handles.amplitude,'String'));
 switch get(handles.inputsignal,'Value')
    case 1  %   Step 
        for t = 1:1:length(TimeVector)
            InputVector(t) = amplitude;
        end
    case 2  %   Impulse 
        for t = 2:1:length(TimeVector)
            InputVector(t) = 0;
        end        
        InputVector(1) = amplitude/plotpoints;
    case 3  %   Pulse
        PulseTime = plotpoints/time*str2double(get(handles.width,'string'));
        for t = 1:1:length(TimeVector)
            if t <= PulseTime
                InputVector(t) = amplitude;
            else
                InputVector(t) = 0;
            end
        end
    case 4  %   Ramp
        InputVector = TimeVector * amplitude;% 1 gives amplitiude of 1 after 1 second
    case 5  %   Sine
        SineFreq = str2double(get(handles.omega,'string')); % omega is in radians per socond
        for t = 1:1:length(TimeVector)
            InputVector(t) = amplitude * sin((t-1)/plotpoints*time * SineFreq);
        end
    case 6  %   Doublet
        DoubletTime = plotpoints/time*str2double(get(handles.width,'string'));
        for t = 1:1:length(TimeVector)
            if t <= DoubletTime/2
                InputVector(t) = amplitude;
            elseif t <= DoubletTime
                InputVector(t) = -amplitude;
            else
                InputVector(t) = 0;
            end
        end
end
