function latplot(handles);

% This function plots the Lateral/Directional time histories, for the
% selected parameters, for the selected input signal.
% By Konstantinos Siliverdis 20-Aug-2004. 
% Modified by M V Cook January 2013

if isstr(get(handles.filename,'String'))
    FigureTitle = get(handles.filename,'String');
else
    FigureTitle = cell2mat(get(handles.filename,'String'));
end

% Perform Lateral/Directional Closed  Loop analysis
[NUMA,NUMR,DEN]=latsolve(handles);

if ~isappdata(0,'ATRANS')
A = geta(handles);
elseif isappdata(0,'ATRANS')
Adim=getappdata(0,'ATRANS');
A=Adim(1:11);
end
V=A(5); % V is used to convert the 'v' numerator into beta numerator
clc;

%[fig flag]=figflag('Time Histories');
%if fig == 1
%    delete(flag)
%    close (flag)
%end

[TimeVector,InputVector]=GetTimeVector(handles);

    switch get(handles.inputsignal,'Value')
        case 1  %   Step 
            inputsignal = 'Step Input';
        case 2  %   Impulse 
            inputsignal = 'Impulse Input';
        case 3  %   Pulse
            inputsignal = 'Pulse Input';
        case 4  %   Ramp
            inputsignal = 'Ramp Input';
        case 5  %   Sine
            inputsignal = 'Sine Input';
        case 6  %   Doublet
            inputsignal = 'Doublet Input';
    end

SYSbetaA=tf(NUMA( 1,:),  DEN,'inputname','Fs','outputname','\beta - Sideslip angle');
SYSpA   =tf(NUMA( 2,:),  DEN,'inputname','Fs','outputname','p - Roll rate');
SYSrA   =tf(NUMA( 3,:),  DEN,'inputname','Fs','outputname','r - Yaw rate');
SYSphiA =tf(NUMA( 4,:),  DEN,'inputname','Fs','outputname','\phi - Roll attitude');
SYSbetaR=tf(NUMR( 1,:),  DEN,'inputname','Fs','outputname','\beta - Sideslip angle');
SYSpR   =tf(NUMR( 2,:),  DEN,'inputname','Fs','outputname','p - Roll rate');
SYSrR   =tf(NUMR( 3,:),  DEN,'inputname','Fs','outputname','r - Yaw rate');
SYSphiR =tf(NUMR( 4,:),  DEN,'inputname','Fs','outputname','\phi - Roll attitude');

p(1) = get(handles.beta_ail_ch, 'Value');
p(2) = get(handles.p_ail_ch, 'Value');
p(3) = get(handles.r_ail_ch, 'Value');
p(4) = get(handles.phi_ail_ch, 'Value');
p(5) = get(handles.beta_r_ch, 'Value');
p(6) = get(handles.p_r_ch, 'Value');
p(7) = get(handles.r_r_ch, 'Value');
p(8) = get(handles.phi_r_ch, 'Value');

totalplots = p(1)+p(2)+p(3)+p(4)+p(5)+p(6)+p(7)+p(8);
switch totalplots
    case {1,2,3}
        plotsacross    =   1;
        plotsdown      =   totalplots;
    case 4
        plotsacross    =   1;% MVC
        plotsdown      =   4;% MVC        
    case {5,6}
        plotsacross    =   2;
        plotsdown      =   3;
    case {7,8}
        plotsacross    =   2;
        plotsdown      =   4;
end

plotted = 1; % Sets initial value for plot counter.

% Set up waitbar window.       
        h=waitbar(0,'Hard sums - please wait...','name','Response Plot in Progress','Position',[460 250 270 56]); 
        %waitbar(0)%MVC
        %set(h,'Visible','on')
        
figure(500) % A large figure number so that it does not interfere with other figures
set(500,'Name','Time Histories','numbertitle','off','Position',[5    35   600   685])
%set(fdacad2,'Pointer','watch');
%figure(500)
if p(1)
    subplot(plotsdown,plotsacross,plotted)
    [x,y]=lsim(SYSbetaA,InputVector,TimeVector);%MVC delete 'b' at end
    lsim(SYSbetaA,'b',InputVector,TimeVector)%MVC move 'b' forward
    axis([min(y) max(y) min(x) max(x)])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Aileron Command','FontSize',8)
    plotted = plotted + 1;
    [num,den]=tfdata(SYSbetaA,'v');
    XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500)
if p(2)
    subplot(plotsdown,plotsacross,plotted)
    [x,y]=lsim(SYSpA,InputVector,TimeVector); %MVC delete 'b' at end
    lsim(SYSpA,'b',InputVector,TimeVector) %MVC move 'b' forward
    axis([min(y) max(y) min(x) max(x)])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Aileron Command','FontSize',8)
    plotted = plotted + 1;
    [num,den]=tfdata(SYSpA,'v');
    XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500)
if p(3)
    subplot(plotsdown,plotsacross,plotted)
    [x,y]=lsim(SYSrA,InputVector,TimeVector);%MVC delete 'b' at end
    lsim(SYSrA,'b',InputVector,TimeVector)%MVC move 'b' forward
    axis([min(y) max(y) min(x) max(x)])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Aileron Command','FontSize',8)
    plotted = plotted + 1;
    [num,den]=tfdata(SYSrA,'v');
    XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500)
if p(4)
    subplot(plotsdown,plotsacross,plotted)
    [x,y]=lsim(SYSphiA,InputVector,TimeVector);%MVC delete 'b' at end
    lsim(SYSphiA,'b',InputVector,TimeVector)%MVC move 'b' forward
    axis([min(y) max(y) min(x) max(x)])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Aileron Command','FontSize',8)
    plotted = plotted + 1;
    [num,den]=tfdata(SYSphiA,'v');
    XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500)
if p(5)
    subplot(plotsdown,plotsacross,plotted)
    [x,y]=lsim(SYSbetaR,InputVector,TimeVector);%MVC delete 'b' at end
    lsim(SYSbetaR,'b',InputVector,TimeVector)%MVC move 'b' forward
    axis([min(y) max(y) min(x) max(x)])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Rudder Command','FontSize',8)
    plotted = plotted + 1;
    [num,den]=tfdata(SYSbetaR,'v');
    XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500)
if p(6)
    subplot(plotsdown,plotsacross,plotted)
    [x,y]=lsim(SYSpR,InputVector,TimeVector);%MVC delete 'b' at end
    lsim(SYSpR,'b',InputVector,TimeVector)%MVC move 'b' forward
    axis([min(y) max(y) min(x) max(x)])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Rudder Command','FontSize',8)
    plotted = plotted + 1;
    [num,den]=tfdata(SYSpR,'v');
    XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500)
if p(7)
    subplot(plotsdown,plotsacross,plotted)
    [x,y]=lsim(SYSrR,InputVector,TimeVector);%MVC delete 'b' at end
    lsim(SYSrR,'b',InputVector,TimeVector)%MVC move 'b' forward
    axis([min(y) max(y) min(x) max(x)])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Rudder Command','FontSize',8)
    plotted = plotted + 1;
    [num,den]=tfdata(SYSrR,'v');
    XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
end
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500)
if p(8)
    subplot(plotsdown,plotsacross,plotted)
    [x,y]=lsim(SYSphiR,InputVector,TimeVector);%MVC delete 'b' at end
    lsim(SYSphiR,'b',InputVector,TimeVector)%MVC move 'b' forward
    axis([min(y) max(y) min(x) max(x)])
    grid on, box on
    title (inputsignal,'FontSize',8)
    ylabel ('Rudder Command','FontSize',8)
    plotted = plotted + 1;
    [num,den]=tfdata(SYSphiR,'v');
    XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
end

figure(500)
t=subplot(1000000,1,1);
set(t,'color','none','Xcolor',[.8 .8 .8], 'Ycolor', [.8 .8 .8])
title(FigureTitle , 'Fontsize', 14)
%set(h,'Visible','on')
waitbar((plotted-1)/totalplots)
%figure(500)
waitbar(1)
close(h)

return