function LatReport( handles )
% This function will output the following Lateral/Directional data to the workspace.
% The A B C D state space matrices
% The response transfer functions in factorised form and
% the System pole locations and pole characteristics. (frequency and
% damping ratio). 
% By Konstantinos Siliverdis 20-Aug-2004 

clc
[NUMA, NUMR, DEN, A, B, C, D]=latsolve(handles);
% V = get(handles.V,'Value');
format('short','g')

if isstr(get(handles.filename,'String'))
    FigureTitle = get(handles.filename,'String');
else
    FigureTitle = cell2mat(get(handles.filename,'String'));
end

if ~isappdata(0,'ATRANS')
temp=['LATERAL/DIRECTIONAL REPORT FOR - ' FigureTitle]; disp(temp);
disp(' ');
elseif isappdata(0,'ATRANS')
switch get(handles.latordir,'value')
    case 1
temp=['LATERAL REPORT FOR - ' FigureTitle]; disp(temp);
     
disp('*-------------------*');
disp('*  xdot = Ax + Bu   *');
disp('*     y = Cx + Du   *');
disp('*-------------------*');

disp('u^T = [     Xi     ]');
disp('x^T = [     beta        p            r          phi  ]');
disp('Control Law :-   ');
    
disp('Xi_d   = delta - Kxi   [u]');

	case 2
temp=['DIRECTIONAL REPORT FOR - ' FigureTitle]; disp(temp);
     
disp('*-------------------*');
disp('*  xdot = Ax + Bu   *');
disp('*     y = Cx + Du   *');
disp('*-------------------*');

disp('u^T = [     Zeta     ]');
disp('x^T = [     beta        p            r          phi  ');
disp('Control Law :-   ');

disp('Zeta_d = delta - Kzeta [u]');
end
end

if isappdata(0,'ATRANS')

switch get(handles.latordir,'value')
    case 1
KphiA   =   get(handles.KphiA,'Value');
KrA     =   get(handles.KrA,'Value');
KpA     =   get(handles.KpA,'Value');
KbetaA  =   get(handles.KbetaA,'Value');
K=[KbetaA KpA KrA KphiA]
SYSbetaA=tf(NUMA( 1,:),DEN,'outputname','beta A - Sideslip due to Aileron');
SYSpA   =tf(NUMA( 2,:),DEN,'outputname','pA - Roll rate due to Aileron');
SYSrA   =tf(NUMA( 3,:),DEN,'outputname','rA - Yaw rate due to Aileron');
SYSphiA =tf(NUMA( 4,:),DEN,'outputname','phi A - Roll attitude due to Aileron');
    case 2
KbetaR  =   get(handles.KbetaR,'Value');
KpR     =   get(handles.KpR,'Value');
KrR     =   get(handles.KrR,'Value');
KphiR   =   get(handles.KphiR,'Value');
K=[KbetaR KpR KrR KphiR]
SYSbetaR=tf(NUMR( 1,:),DEN,'outputname','beta R - Sideslip due to Rudder');
SYSpR   =tf(NUMR( 2,:),DEN,'outputname','pR - Roll rate due to Rudder');
SYSrR   =tf(NUMR( 3,:),DEN,'outputname','rR - Yaw rate due to Rudder');
SYSphiR =tf(NUMR( 4,:),DEN,'outputname','phi R - Roll attitude due to Rudder');
end

else
SYSbetaA=tf(NUMA( 1,:),DEN,'outputname','beta A - Sideslip due to Aileron');
SYSpA   =tf(NUMA( 2,:),DEN,'outputname','pA - Roll rate due to Aileron');
SYSrA   =tf(NUMA( 3,:),DEN,'outputname','rA - Yaw rate due to Aileron');
SYSphiA =tf(NUMA( 4,:),DEN,'outputname','phi A - Roll attitude due to Aileron');
SYSbetaR=tf(NUMR( 1,:),DEN,'outputname','beta R - Sideslip due to Rudder');
SYSpR   =tf(NUMR( 2,:),DEN,'outputname','pR - Roll rate due to Rudder');
SYSrR   =tf(NUMR( 3,:),DEN,'outputname','rR - Yaw rate due to Rudder');
SYSphiR =tf(NUMR( 4,:),DEN,'outputname','phi R - Roll attitude due to Rudder');
disp(sprintf('K=[0 0 0 0\n   0 0 0 0]'))
end


disp('STATE SPACE MATRICES :-   ');
A
B_transposed = B'
C
D_transposed = D'

disp(' ');
disp('TRANSFER FUNCTIONS - FACTORISED FORM');

if ~isappdata(0,'ATRANS')
zpk(SYSbetaA)
zpk(SYSpA)
zpk(SYSrA)
zpk(SYSphiA)
zpk(SYSbetaR)
zpk(SYSpR)
zpk(SYSrR)
zpk(SYSphiR)
elseif isappdata(0,'ATRANS')
switch get(handles.latordir,'value')
    case 1
zpk(SYSbetaA)
zpk(SYSpA)
zpk(SYSrA)
zpk(SYSphiA)
	case 2
zpk(SYSbetaR)
zpk(SYSpR)
zpk(SYSrR)
zpk(SYSphiR)
end
end
        
% disp(' ');
% disp('TRANSFER FUNCTIONS - CONCISE FORM');
% disp(' ');
% 
% temp = ['Lat DEN    ' concise(DEN,DEN) ] ;          disp(temp)
% temp = ['SYSbetaA   ' concise(NUMA( 1,:),DEN)];     disp(temp)
% temp = ['SYSpA      ',concise(NUMA( 2,:),DEN)];     disp(temp)
% temp = ['SYSrA      ',concise(NUMA( 3,:),DEN)];     disp(temp)
% temp = ['SYSphiA    ',concise(NUMA( 4,:),DEN)];     disp(temp)
% temp = ['SYSbetaR   ',concise(NUMR( 1,:),DEN)];     disp(temp)
% temp = ['SYSpR      ',concise(NUMR( 2,:),DEN)];     disp(temp)
% temp = ['SYSrR      ',concise(NUMR( 3,:),DEN)];     disp(temp)
% temp = ['SYSphiR    ',concise(NUMR( 4,:),DEN)];     disp(temp)

disp([' '])
disp('CHARACTERISTIC POLE LOCATIONS');
damp(DEN)



