function [NUMA, NUMR, DENA, A,B,C,D,Wn,z,Bbas,Abas,Cbas,Dbas]=latsolve(handles);

% This function solves the Full Order Lateral/Directional equations of motion.
% Originally developed by Rees 2003, modified by,
% Konstantinos Siliverdis 20-Aug-2004 
% Modified by MVC February 2013

clc;

if ~isappdata(0,'ATRANS')
    
A = geta(handles);
if A(29)==1       % Dimensional
Adim=A;
elseif A(29)== 2  % Normalised. This case modified to match USA standard MVC
Adim=norm2dal(A);
elseif A(29)==3   % Dimensionless
Adim=dless2dal(A);
end;

% Dimensionalise derivatives as neccessary for state equation solution%

elseif isappdata(0,'ATRANS')
Adim=getappdata(0,'ATRANS');
A=Adim(1:11);
end

m=Adim(6);
g=Adim(13);
V=Adim(5);
Ix=Adim(7);
Iz=Adim(8);
Ixz=Adim(9);
Yv=Adim(14);
Yp=Adim(15);
Yr=Adim(16);
Yda=Adim(17);
Ydr=Adim(18);
Lv=Adim(19);
Lp=Adim(20);
Lr=Adim(21);
Lda=Adim(22);
Ldr=Adim(23);
Nv=Adim(24);
Np=Adim(25);
Nr=Adim(26);
Nda=Adim(27);
Ndr=Adim(28);
alpha=A(4)*pi/180;
theta=(A(3)+A(4))*pi/180;

%   Aircraft Model
% Standard universal solution - MVC
%       v                p                   r             phi     

M = [   m                   0                   0               0
        0                  Ix                -Ixz               0
        0                -Ixz                  Iz               0
        0                   0                   0               1];
    
     %      v                  p                    r             phi     
a =[    Yv  Yp+V*sin(alpha)*m    Yr-m*V*cos(alpha)  m*g*cos(theta)
        Lv                  Lp                  Lr              0
        Nv                  Np                  Nr              0
        0                   1              tan(alpha)           0];

%       Aileron Rudder   
b =[    Yda       Ydr
        Lda       Ldr
        Nda       Ndr
        0           0];      

A   =   inv(M)*a; 
B   =   inv(M)*b;
    if isnan(A) % check for errors
        %set(fdacad,'Pointer','custom');
        errordlg('Aircraft data is incomplete or invalid.','Invalid Data','modal'),
        clc
        return
    end

C   =   eye(4);
D   =   zeros(4,2);
SYSac = ss(A,B,C,D, 'inputname',{'Aileron' 'Rudder'},...
                        'outputname',{'\beta' 'p' 'r' '\phi'});
[NUMA,DENA]=ss2tf(A,B,C,D,1);
[NUMR,DEN]=ss2tf(A,B,C,D,2);

NUMA(1,:)=NUMA(1,:)/V;% Sideslip output is beta MVC
NUMR(1,:)=NUMR(1,:)/V;% Sideslip output is beta MVC

Bbas=B;,Abas=A;,Cbas=C;,Dbas=D;
%   setb to zero any numerator coefficients < 10^-8
index=find(abs(NUMR)<10^-8);
NUMR(index)=0;
index=find(abs(NUMA)<10^-8);
NUMA(index)=0;

[Wn z]  =   damp(DENA);
roots   =   eig(A);

if ~isappdata(0,'ATRANS')
set(handles.Wn,'String',Wn);
set(handles.Z,'String',z);
else
end

if isappdata(0,'ATRANS') %The Stability and Control Window is open



%   retrieve values from GUI
RactNUM  =   str2num(get(handles.RactNUM, 'String'));
RactDEN  =   str2num(get(handles.RactDEN, 'String'));
AactNUM  =   str2num(get(handles.AactNUM, 'String'));
AactDEN  =   str2num(get(handles.AactDEN, 'String'));


KbetaR   =   str2num(get(handles.KbetaR,'string'))/V;
KpR      =   str2num(get(handles.KpR,  'string'));
KrR      =   str2num(get(handles.KrR,  'string'));
KphiR    =   str2num(get(handles.KphiR,'string'));
Kari    =    str2num(get(handles.Kari, 'string'));
KbetaA   =   str2num(get(handles.KbetaA,'string'))/V;
KpA      =   str2num(get(handles.KpA,   'string'));
KrA      =   str2num(get(handles.KrA,   'string'));
KphiA    =   str2num(get(handles.KphiA, 'string'));

    
%   Actuator Models
SYSactA =   tf(AactNUM, AactDEN);
SYSactR =   tf(RactNUM, RactDEN);


%   Command Path models
SYSKaa = tf([1],[1]);
SYSKari = tf([Kari],[1]);
SYSKrai = tf([0],[1]);
SYSKrr = tf([1],[1]);

%   Feedback models
    SYSKbetaA = tf([KbetaA],[1]);
    SYSKpA = tf([KpA],[1]);
    SYSKrA = tf([KrA],[1]);
    SYSKphiA = tf([KphiA],[1]);

    SYSKbetaR = tf([KbetaR],[1]);
    SYSKpR = tf([KpR],[1]);
    SYSKrR = tf([KrR],[1]);
    SYSKphiR = tf([KphiR],[1]);
%APPEND all system blocks
SYS = append(SYSac, SYSactA, SYSactR, SYSKaa, SYSKari, SYSKrai, SYSKrr,...
             SYSKphiA, SYSKrA, SYSKpA, SYSKbetaA, SYSKbetaR, SYSKpR, SYSKrR, SYSKphiR,1,1);
%CONNECT all system blocks
Q   =   [   1   5   0   0   0   0   0
            2   6   0   0   0   0   0
            3   7   9  -11 -12 -13 -14
            4   8   10 -15 -16 -17 -18
            5   19  0   0   0   0   0
            6   19  0   0   0   0   0
            7   20  0   0   0   0   0
            8   20  0   0   0   0   0
            9   4   0   0   0   0   0
            10  3   0   0   0   0   0
            11  2   0   0   0   0   0
            12  1   0   0   0   0   0
            13  1   0   0   0   0   0
            14  2   0   0   0   0   0
            15  3   0   0   0   0   0
            16  4   0   0   0   0   0];
inputs = [  17  18];
outputs = [ 1   2   3   4];
SYSTEM = connect(SYS,Q,inputs,outputs);
[A,B,C,D] = ssdata(SYSTEM);

[NUMR,DENR]=ss2tf(A,B,C,D,2);
[NUMA,DENA]=ss2tf(A,B,C,D,1);
%   remove any numerator coefficients < 10^-12
index=find(abs(NUMA)<=10^-12);
NUMA(index)=0;
index=find(abs(NUMR)<=10^-12);
NUMR(index)=0;

NUMA( 1,:) = NUMA( 1,:)/V; % convert v to beta
NUMR( 1,:) = NUMR( 1,:)/V; % convert v to beta

SYSbetaA=tf(NUMA( 1,:),DENA,'inputname','Fs','outputname','vA - Lateral velocity perturbation due to Aileron');
SYSpA   =tf(NUMA( 2,:),DENA,'inputname','Fs','outputname','pA - Roll rate due to Aileron');
SYSrA   =tf(NUMA( 3,:),DENA,'inputname','Fs','outputname','rA - Yaw rate due to Aileron');
SYSphiA =tf(NUMA( 4,:),DENA,'inputname','Fs','outputname','phiA - Roll attitude due to Aileron');
SYSbetaR=tf(NUMR( 1,:),DENR,'inputname','Fs','outputname','vR - Lateral velocity perturbation due to Rudder');
SYSpR   =tf(NUMR( 2,:),DENR,'inputname','Fs','outputname','pR - Roll rate due to Rudder');
SYSrR   =tf(NUMR( 3,:),DENR,'inputname','Fs','outputname','rR - Yaw rate due to Rudder');
SYSphiR =tf(NUMR( 4,:),DENR,'inputname','Fs','outputname','phiR - Roll attitude due to Rudder');


[Wn z]  =   damp(DENA);
roots   =   eig(A);
set(handles.Wn,'String',Wn);
set(handles.Z,'String',z);


 if length(z) == 4
     set(handles.LatPolePlacement,'Enable','on')
 else
     set(handles.LatPolePlacement,'Enable','off')
 end
 
%find position of real & complex pole positions within the z vector
countreal=0;
countcomp=0;
RealPole(1)=0;
CompPole(1)=0;
for temp = 1:length(z)
    if abs(z(temp)) == 1; 
        countreal = countreal + 1;
        RealPole(countreal) = temp; 
    else
        countcomp = countcomp +1;
        CompPole(countcomp) = temp;
    end;
end;       

 NumPoles = length (Wn);
 pos = countreal - length(AactDEN) - length (RactDEN) + 2;
 switch pos 
    %   Assume that actuator roots will remain higher that other system roots    
    case 0 % 4 complex roots
        set(handles.SpiralMode, 'Value', Wn(CompPole(1)),...
								'ForegroundColor', [0 0 0],...
								'String', round(Wn(CompPole(1))*10000)/10000);
        set(handles.RollMode,   'Value', z(CompPole(2)),...
                                'ForegroundColor', [0 0 0],...
                                'String', round(z(CompPole(2))*10000)/10000);
        set(handles.Wdr,        'Value', Wn(CompPole(3)),...
                                'ForegroundColor', [0 0 0],...
                                'String', round(Wn(CompPole(3))*10000)/10000);
        set(handles.Zdr,        'Value', z(CompPole(4)),...
                                'ForegroundColor', [0 0 0],...
                                'String', round(z(CompPole(4))*10000)/10000);
    case 2    % 1 complex pair and 2 real roots
        if RealPole(1) == 3     % Dutch Roll poles are real
            set(handles.Wdr,        'Value', Wn(RealPole(1))*z(RealPole(1)),...
                                    'ForegroundColor', [0 0 1],...
                                    'String', round(Wn(RealPole(1))*z(RealPole(1))*10000)/10000);
            set(handles.Zdr,        'Value', Wn(RealPole(2))*z(RealPole(2)),...
                                    'ForegroundColor', [0 0 1],...
                                    'String', round(Wn(RealPole(2))*z(RealPole(2))*10000)/10000);
            set(handles.SpiralMode, 'Value', Wn(CompPole(1)),...
                                    'ForegroundColor', [0 0 0],...
                                    'String', round(Wn(CompPole(1))*10000)/10000);
            set(handles.RollMode,   'Value', z(CompPole(2)),...
                                    'ForegroundColor', [0 0 0],...
                                    'String', round(z(CompPole(2))*10000)/10000);
        else                    % Spiral and Roll mode poles are real
            set(handles.SpiralMode, 'Value', Wn(RealPole(1))*z(RealPole(1)),...
                                    'ForegroundColor', [0 0 1],...
                                    'String', round(Wn(RealPole(1))*z(RealPole(1))*10000)/10000);
            set(handles.RollMode,   'Value', Wn(RealPole(2))*z(RealPole(2)),...
                                    'ForegroundColor', [0 0 1],...
                                    'String', round(Wn(RealPole(2))*z(RealPole(2))*10000)/10000);
            set(handles.Wdr,        'Value', Wn(CompPole(1)),...
                                    'ForegroundColor', [0 0 0],...
                                    'String', round(Wn(CompPole(1))*10000)/10000);
            set(handles.Zdr,        'Value', z(CompPole(2)),...
                                    'ForegroundColor', [0 0 0],...
                                    'String', round(z(CompPole(2))*10000)/10000);            
        end
    case 4  % 4 real roots
        set(handles.SpiralMode, 'Value', Wn(RealPole(1))*z(RealPole(1)),...
                                'ForegroundColor', [0 0 1],...
                                'String', round(Wn(RealPole(1))*z(RealPole(1))*10000)/10000);
        set(handles.RollMode,   'Value', Wn(RealPole(2))*z(RealPole(2)),...
                                'ForegroundColor', [0 0 1],...
                                'String', round(Wn(RealPole(2))*z(RealPole(2))*10000)/10000);
        set(handles.Wdr,        'Value', Wn(RealPole(3))*z(RealPole(3)),...
                                'ForegroundColor', [0 0 1],...
                                'String', round(Wn(RealPole(3))*z(RealPole(3))*10000)/10000);
        set(handles.Zdr,        'Value', Wn(RealPole(4))*z(RealPole(4)),...
                                'ForegroundColor', [0 0 1],...
                                'String', round(Wn(RealPole(4))*z(RealPole(4))*10000)/10000);    
end
end   %of 'if isapp(0,'ATRANS')'
return

