function Longplot (handles)
% This function plots the longitudinal time histories for the 
% selected variables.
% Plots full order or reduced order solution as selected.
% By Konstantinos Siliverdis 20-Aug-2004
% Modified by M.V.Cook January 2013.

%FigureTitle = get(handles.FigureTitle, 'String');
if isstr(get(handles.filename,'String'))
    FigureTitle = get(handles.filename,'String');
else
    FigureTitle = cell2mat(get(handles.filename,'String'));
end

%[fig flag]=figflag('Time Histories');
%if fig == 1
%    delete(flag)
%end



[TimeVector,InputVector]=GetTimeVector(handles);

    switch get(handles.inputsignal,'Value')
        case 1  %   Step 
            inputsignal = 'Step Input';
        case 2  %   Impulse 
            inputsignal = 'Impulse Input';
        case 3  %   Pulse
            inputsignal = 'Pulse Input';
        case 4  %   Ramp
            inputsignal = 'Ramp Input';
        case 5  %   Sine
            inputsignal = 'Sine Input';
        case 6  %   Doublet
            inputsignal = 'Doublet Input';
    end

    %inputsignal % MVC
    %mo=get(handles.ModelOrder, 'Value')%;MVC
    mo=getappdata(0, 'mo')%;MVC
if mo==1 
    %case 1 % Full Order Longitudinal Model Selected     
        if isappdata(0,'STATUS')
        [NUM,DEN,SYS]=longsholvehq(handles);
        else
        [NUM,DEN] = Longsolve(handles);
        end
        
        SYSu    =tf(NUM( 1,:),DEN,'inputname','Fs','outputname','u - Axial velocity');
        SYSw    =tf(NUM( 2,:),DEN,'inputname','Fs','outputname','w - Normal velocity');
        SYSq    =tf(NUM( 3,:),DEN,'inputname','Fs','outputname','q - Pitch rate');
        SYStheta=tf(NUM( 4,:),DEN,'inputname','Fs','outputname','\theta - Pitch attitude');
        SYSaz   =tf(NUM( 5,:),DEN,'inputname','Fs','outputname','Az - Normal acceleration');
        SYSalpha=tf(NUM( 6,:),DEN,'inputname','Fs','outputname','\alpha - Angle of attack');
        SYSgamma=tf(NUM( 7,:),DEN,'inputname','Fs','outputname','\gamma - Flight path angle');
        SYSh    =tf(NUM( 8,:),DEN,'inputname','Fs','outputname','dh - Height rate');
       
        p(1) = get(handles.u_lon_ch, 'Value');
        p(2) = get(handles.w_lon_ch, 'Value');
        p(3) = get(handles.q_lon_ch, 'Value');
        p(4) = get(handles.theta_lon_ch, 'Value');
        p(5) = get(handles.az_lon_ch, 'Value');
        p(6) = get(handles.a_lon_ch, 'Value');
        p(7) = get(handles.gamma_lon_ch, 'Value');
        p(8) = get(handles.h_lon_ch, 'Value');
        
        % Determine the number of plot variables selected
        totalplots = p(1)+p(2)+p(3)+p(4)+p(5)+p(6)+p(7)+p(8);
        
elseif mo==2 % Reduced Order Longitudinal Model Selected    
        [NUM,DEN] = ShortSolve(handles);        
        
        SYSw    =tf(NUM( 1,:),DEN,'inputname','Fs','outputname','w - Normal velocity');
        SYSq    =tf(NUM( 2,:),DEN,'inputname','Fs','outputname','q - Pitch rate');
        SYStheta=tf(NUM( 3,:),DEN,'inputname','Fs','outputname','\theta - Pitch attitude');
        SYSaz   =tf(NUM( 4,:),DEN,'inputname','Fs','outputname','Az - Normal acceleration');
        SYSalpha=tf(NUM( 5,:),DEN,'inputname','Fs','outputname','\alpha - Angle of attack');
        SYSgamma=tf(NUM( 6,:),DEN,'inputname','Fs','outputname','\gamma - Flight path angle');
        SYSh    =tf(NUM( 7,:),DEN,'inputname','Fs','outputname','h - Height');
                       
        %p(1) = get(handles.u_lon_ch, 'Value');
       
        p(1) = 0; % MVC
        p(2) = get(handles.w_lon_ch, 'Value');
        p(3) = get(handles.q_lon_ch, 'Value');
        p(4) = get(handles.theta_lon_ch, 'Value');
        p(5) = get(handles.az_lon_ch, 'Value');
        p(6) = get(handles.a_lon_ch, 'Value');
        p(7) = get(handles.gamma_lon_ch, 'Value');
        p(8) = get(handles.h_lon_ch, 'Value');
        
       % Determine the number of plot variables selected 
        totalplots = p(1)+p(2)+p(3)+p(4)+p(5)+p(6)+p(7)+p(8);
end% MVC           
        
       % Plots layout on page
        switch totalplots
            case {1,2,3}
                plotsacross    =   1;
                plotsdown      =   totalplots;
            case 4
                plotsacross    =   1;% MVC
                plotsdown      =   4;% MVC        
            case {5,6}
                plotsacross    =   2;
                plotsdown      =   3;
            case {7,8}
                plotsacross    =   2;
                plotsdown      =   4;
        end
        
     
         plotted = 1 % Start plot counter - initial value
        
     % Set up waitbar window.       
        h=waitbar(0,'Hard sums - please wait...','name','Response Plot in Progress','Position',[460 250 270 56]); 
        %waitbar(0)%MVC
        %set(h,'Visible','on')
        
         % Choose a large figure number so that it does not interfere with other figures
        figure(500);
        set(500,'Name','Time Histories','numbertitle','off','Position',[5    35   600   685])%MVC - position changes
                   
        %set(fdacad3,'Pointer','watch') 
        %figure(500);
        if p(1)
            subplot(plotsdown,plotsacross,plotted)
            [x,y]=lsim(SYSu,InputVector,TimeVector);
            lsim(SYSu,'b',InputVector,TimeVector)
            axis([min(y) max(y) min(x) max(x)])
            grid on, box on
            title(inputsignal,'FontSize',8)
            ylabel('Elevator Command','FontSize',8)
            plotted = plotted + 1;
            [num,den]=tfdata(SYSu,'v');
            XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
        end
        %set(h,'Visible','on')
        waitbar((plotted-1)/totalplots)
        %figure(500);
        if p(2)
            subplot(plotsdown,plotsacross,plotted)
            [x,y]=lsim(SYSw,InputVector,TimeVector);
            lsim(SYSw,'b',InputVector,TimeVector)
            axis([min(y) max(y) min(x) max(x)])
            grid on, box on
            title(inputsignal,'FontSize',8)
            ylabel('Elevator Command','FontSize',8)
            plotted = plotted + 1;
            [num,den]=tfdata(SYSw,'v');
            XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
            %keyboard
        end
       % set(h,'Visible','on')
        waitbar((plotted-1)/totalplots)
        %figure(500);
        if p(3)
            subplot(plotsdown,plotsacross,plotted)
            [x,y]=lsim(SYSq,InputVector,TimeVector);
            lsim(SYSq,'b',InputVector,TimeVector)
            axis([min(y) max(y) min(x) max(x)])
            grid on, box on
            title(inputsignal,'FontSize',8)
            ylabel('Elevator Command','FontSize',8)
            plotted = plotted + 1;
            [num,den]=tfdata(SYSq,'v');
            XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
        end
        %set(h,'Visible','on')
        waitbar((plotted-1)/totalplots)
        %figure(500);
        if p(4)
            subplot(plotsdown,plotsacross,plotted)
            [x,y]=lsim(SYStheta,InputVector,TimeVector);
            lsim(SYStheta,'b',InputVector,TimeVector)
            axis([min(y) max(y) min(x) max(x)])
            grid on, box on
            title(inputsignal,'FontSize',8)
            ylabel('Elevator Command','FontSize',8)
            plotted = plotted + 1;
            [num,den]=tfdata(SYStheta,'v');
            XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
        end
        %set(h,'Visible','on')
        waitbar((plotted-1)/totalplots)
        %figure(500);
        if p(5)
            subplot(plotsdown,plotsacross,plotted)
            [x,y]=lsim(SYSaz,InputVector,TimeVector);
            lsim(SYSaz,'b',InputVector,TimeVector)
            axis([min(y) max(y) min(x) max(x)])
            grid on, box on
            title(inputsignal,'FontSize',8)
            ylabel('Elevator Command','FontSize',8)
            plotted = plotted + 1;
            [num,den]=tfdata(SYSaz,'v');
            XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
        end
        %set(h,'Visible','on')
        waitbar((plotted-1)/totalplots)
        %figure(500);
        if p(6)
            subplot(plotsdown,plotsacross,plotted)
            [x,y]=lsim(SYSalpha,InputVector,TimeVector);
            lsim(SYSalpha,'b',InputVector,TimeVector)
            axis([min(y) max(y) min(x) max(x)])
            grid on, box on
            title(inputsignal,'FontSize',8)
            ylabel ('Elevator Command','FontSize',8)
            plotted = plotted + 1;
            [num,den]=tfdata(SYSalpha,'v');
            XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
        end
        %set(h,'Visible','on')
        waitbar((plotted-1)/totalplots)
        %figure(500);
        if p(7)
            subplot(plotsdown,plotsacross,plotted)
            [x,y]=lsim(SYSgamma,InputVector,TimeVector);
            lsim(SYSgamma,'b',InputVector,TimeVector)
            axis([min(y) max(y) min(x) max(x)])
            grid on, box on
            title(inputsignal,'FontSize',8)
            ylabel('Elevator Command','FontSize',8)
            plotted = plotted + 1;
            [num,den]=tfdata(SYSgamma,'v');
            XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
        end
        %set(h,'Visible','on')
        waitbar((plotted-1)/totalplots)
        %figure(500);
        if p(8)
            subplot(plotsdown,plotsacross,plotted)
            [x,y]=lsim(SYSh,InputVector,TimeVector);
            lsim(SYSh,'b',InputVector,TimeVector)
            axis([min(y) max(y) min(x) max(x)])
            grid on, box on
            title(inputsignal,'FontSize',8)
            ylabel ('Elevator Command','FontSize',8)
            plotted = plotted + 1;
            [num,den]=tfdata(SYSh,'v');
            XferFn2Plot( handles,num,den,[min(x) max(x) min(y) max(y)])
        end
        
        %set(fdacad3,'Pointer','arrow');
        %set(h,'Visible','on')
        waitbar((plotted-1)/totalplots)
        %set(fdacad3,'Pointer','custom');
        figure(500);
        t=subplot(1000000,1,1);
        set(t,'color','none','Xcolor',[.8 .8 .8], 'Ycolor', [.8 .8 .8])
        title(FigureTitle,'Fontsize',14)
        waitbar(1)
        close(h)
        
return    
