function [A,B] = Longpolesolve (handles)

% This function is called by the Pole Placement.
% Update the GUI with feedback path gains to provide the desired system
% performance. Originally created by Rees 2003, modified by
% Konstantinos Siliverdis 20-Aug-2004 
clc


Adim=getappdata(0,'ATRANS');
A=Adim(1:11);
set(handles.Wp,'Enable','on')
set(handles.Zp,'Enable','on')



m=Adim(6);
g=Adim(11);
V=Adim(5);
Iy=Adim(7);
Xu=Adim(12);
Xw=Adim(13);
Xdw=Adim(14);
Xq=Adim(15);
Xde=Adim(16);
Zu=Adim(17);
Zw=Adim(18);
Zdw=Adim(19);
Zq=Adim(20);
Zde=Adim(21);
Mu=Adim(22);
Mw=Adim(23);
Mdw=Adim(24);
Mq=Adim(25);
Mde=Adim(26);
theta=(A(3)+A(4))*pi/180;

%   Aircraft Model
%       u       w       q                   theta
M =[    m       -Xdw    0                   0
        0       m-Zdw   0                   0
        0       -Mdw    Iy                  0
        0       0       0                   1];
a =[    Xu      Xw      Xq-m*V*sin(theta)   -m*g*cos(theta)
        Zu      Zw      m*V*cos(theta)+Zq   -m*g*sin(theta)
        Mu      Mw      Mq                  0
        0       0       1                   0];
b =[    Xde;    Zde;    Mde;                0];        
A   =   inv(M)*a; 
B   =   inv(M)*b;
[Acol,Arow]=size(A);
C   =   eye(Acol);
[Cr,Cc]=size(C);
D   =   zeros(Cr,1);
SYSac = ss(A,B,C,D);
               
%   retrieve values from GUI
actNUM  =   str2num(get(handles.actNUM, 'String'));
actDEN  =   str2num(get(handles.actDEN, 'String'));

%   Actuator Model
SYSact  =   tf([actNUM], [actDEN]);
SYSact  =   tf([1],[1]);    % removed the actuator 

%APPEND all system blocks
SYS = append(SYSac, SYSact);
%CONNECT all system blocks
Q   =   [1 5];
inputs = [2];
outputs = [1 2 3 4];
SYSTEM = connect(SYS,Q,inputs,outputs);
[A,B,C,D] = ssdata(SYSTEM);
[NUM,DEN]=ss2tf(A,B,C,D);

%   get the values for Ws, Zs, Wp, & Zp.
    Ws      =   get(handles.Ws, 'Value'); 
    Wp      =   get(handles.Wp, 'Value');
    Zs      =   get(handles.Zs, 'Value');
    Zp      =   get(handles.Zp, 'Value');
%   determine if the roots are 2 complex pairs or just 1 complex pair and 2 real roots  

Z = get(handles.Z,'String');
if get(handles.Wp,'ForegroundColor') == [0 0 0]
    PhugoidType = 'Complex';
else
    PhugoidType = 'Real';
end
if get(handles.Ws,'ForegroundColor') == [0 0 0]
    ShortType = 'Complex';
else
    ShortType = 'Real';
end
switch PhugoidType
    case 'Real' % solve for complex pair and 2 real roots
        k1   =   conv([1 Wp],[1 Zp]);
    case 'Complex' % solve for 2 complex pairs
        k1   =   [1 2*Wp*Zp  Wp^2];
end
switch ShortType
    case 'Real' % solve for complex pair and 2 real roots
        k2   =   conv([1 Ws],[1 Zs]);
    case 'Complex' % solve for 2 complex pairs
        k2   =   [1 2*Zs*Ws Ws^2];
end
k   =   tf([1],conv(k1,k2));
    
    roots = eig(k);
    K  =   place(A, B, roots);
%   assign the new K values to the GUI
    set(handles.Ku,     'String', round(K(1)*10000)/10000, 'Value', K(1)); 
    set(handles.Kw,     'String', round(K(2)*10000)/10000, 'Value', K(2));  
    set(handles.Kq,     'String', round(K(3)*10000)/10000, 'Value', K(3)); 
    set(handles.Ktheta, 'String', round(K(4)*10000)/10000, 'Value', K(4)); 

return    
