function LongReport( handles )

% This function will output the following Longitudinal data to the workspace.
% The A B C D state space matrices
% The response transfer functions in factorised form and
% the System pole locations and pole characteristics. (frequency and
% damping ratio. Originally written by Rees 2003 modified by
% Konstantinos Siliverdis 20-Aug-2004
% Modeified by M V Cook February 2013

clc
if ~isappdata(0,'STATUS')
[NUM,DEN,A,B,C,D]=LongSolve(handles);% Basic 4th order aircraft model
elseif isappdata(0,'STATUS')
[NUM,DEN,SYS]=longsholvehq(handles);% Higher order aircraft model with feedback, etc?
A=SYS.a;,B=SYS.b;,C=SYS.c;,D=SYS.d;
end

if getappdata(0,'mo')==1 % Selects full order basic aircraft model MVC

format('short','g')
if isstr(get(handles.filename,'String'))
    FigureTitle = get(handles.filename,'String');
else
    FigureTitle = cell2mat(get(handles.filename,'String'));
end
temp=['LONGITUDINAL REPORT FOR - ' FigureTitle]; disp(temp);
disp(' ');

disp('*-------------------*');
disp('*  xdot = Ax + Bu   *');
disp('*     y = Cx + Du   *');
disp('*-------------------*');

disp('u^T = [     Eta        ]');
disp('x^T = [     u            w            q        theta ]');
disp('Control Law :-   ');
disp('eta_d = delta - K [u]');

if ~isappdata(0,'ATRANS')
K=[0 0 0 0]
elseif isappdata(0,'ATRANS') & ~isappdata(0,'STATUS')
Ku = get(handles.Ku,'Value');
Kw = get(handles.Kw,'Value');
Kq = get(handles.Kq,'Value');
Ktheta = get(handles.Ktheta,'Value');
K=[Ku Kw Kq Ktheta]
elseif isappdata(0,'ATRANS')
acdyn=getappdata(0,'ACDYN');
K=[acdyn{9} acdyn{10} acdyn{11} acdyn{12}];
end

disp('STATE SPACE MATRICES :-   ');
A
B_transposed = B'
C
D_transposed = D'

SYSu    =tf(NUM( 1,:),DEN,'outputname','u - Axial velocity');
SYSw    =tf(NUM( 2,:),DEN,'outputname','w - Normal velocity');
SYSq    =tf(NUM( 3,:),DEN,'outputname','q - Pitch rate');
SYStheta=tf(NUM( 4,:),DEN,'outputname','theta - Pitch attitude');
SYSaz   =tf(NUM( 5,:),DEN,'outputname','Az - Normal acceleration');
SYSalpha=tf(NUM( 6,:),DEN,'outputname','alpha - Angle of attack');
SYSgamma=tf(NUM( 7,:),DEN,'outputname','gamma - Flight path angle');
SYSh    =tf(NUM( 8,:),DEN,'outputname','dh - height rate');

disp(' ');
disp('TRANSFER FUNCTIONS - FACTORISED FORM');
zpk(SYSu)
zpk(SYSw)
zpk(SYSq)
zpk(SYStheta)
zpk(SYSaz)
zpk(SYSalpha)
zpk(SYSgamma)
zpk(SYSh)


disp([' '])
disp('CHARACTERISTIC POLE LOCATIONS');
damp(DEN)
end

%==========================================================================
if getappdata(0,'mo') == 2 % Selects reduced order basic aircraft model MVC
   [NUM,DEN,A,B,C,D]=ShortSolve(handles);

  format('short','g')
if isstr(get(handles.filename,'String'))
    FigureTitle = get(handles.filename,'String');
else
    FigureTitle = cell2mat(get(handles.filename,'String'));
end
temp=['LONGITUDINAL REDUCED ORDER REPORT FOR - ' FigureTitle]; disp(temp);
disp(' ');

disp('*-------------------*');
disp('*  xdot = Ax + Bu   *');
disp('*     y = Cx + Du   *');
disp('*-------------------*');

disp('u^T = [     Eta        ]');
disp('x^T = [     w            q        theta ]');

disp('STATE SPACE MATRICES :-   ');
A
B_transposed = B'
C
D_transposed = D'

SYSw    =tf(NUM( 1,:),DEN,'outputname','w - Normal velocity');
SYSq    =tf(NUM( 2,:),DEN,'outputname','q - Pitch rate');
SYStheta=tf(NUM( 3,:),DEN,'outputname','theta - Pitch attitude');
SYSaz   =tf(NUM( 4,:),DEN,'outputname','Az - Normal acceleration');
SYSalpha=tf(NUM( 5,:),DEN,'outputname','alpha - Angle of attack');
SYSgamma=tf(NUM( 6,:),DEN,'outputname','gamma - Flight path angle');
SYSh    =tf(NUM( 7,:),DEN,'outputname','dh - height rate');


disp(' ');
disp('TRANSFER FUNCTIONS - FACTORISED FORM');
zpk(SYSw)
zpk(SYSq)
zpk(SYStheta)
zpk(SYSaz)
zpk(SYSalpha)
zpk(SYSgamma)
zpk(SYSh)


disp([' '])
disp('CHARACTERISTIC POLE LOCATIONS');
damp(DEN)
end 
   
   
 