function [NUM,DEN,A,B,C,D,Wn,z,Bbas,Abas,Cbas,Dbas] = Longsolve (handles)

% This function solves the Full Order Longitudinal equations of motion.
% It returns the full order longitudinal dynamics numerators, denominator
% and the state-space matrices representing that system. Originally created
% by Rees 2003, modified by,
% Konstantinos Siliverdis 20-Aug-2004 
% modified jfw 19-Sept-2005 to correct error in a matrix for 
% non-level flight: terms a_13, a_23 are dependent on alpha, not theta
clc

if ~isappdata(0,'ATRANS') & ~isappdata(0,'ATRANSHQ') % Basic a/c screen
    A = geta(handles);

    if A(27)==1
        Adim=A;
    elseif A(27)== 2
        Adim=norm2dal(A);
    elseif A(27)==3
        Adim=dless2dal(A);
    end;
    
elseif isappdata(0,'ATRANS') & ~isappdata(0,'ATRANSHQ') % Stability and Control Screen
    Adim=getappdata(0,'ATRANS');
    A=Adim(1:11);
    set(handles.Wp,'visible','on')
    set(handles.Zp,'visible','on')
    
elseif ~isappdata(0,'ATRANS') & isappdata(0,'ATRANSHQ') % Handling Qualities Screen
    Adim=getappdata(0,'ATRANSHQ');
    A=Adim(1:11);
end



m=Adim(6);
g=Adim(11);
V=Adim(5);
Iy=Adim(7);
Xu=Adim(12);
Xw=Adim(13);
Xdw=Adim(14);
Xq=Adim(15);
Xde=Adim(16);
Zu=Adim(17);
Zw=Adim(18);
Zdw=Adim(19);
Zq=Adim(20);
Zde=Adim(21);
Mu=Adim(22);
Mw=Adim(23);
Mdw=Adim(24);
Mq=Adim(25);
Mde=Adim(26);
alpha=A(4)*pi/180;  % added jfw 19-Sept-2005
theta=(A(3)+A(4))*pi/180;

%   Aircraft Model
%       u       w       q                   theta
M =[    m       -Xdw    0                   0
        0       m-Zdw   0                   0
        0       -Mdw    Iy                  0
        0       0       0                   1];
a =[    Xu      Xw      Xq-m*V*sin(alpha)   -m*g*cos(theta) % corrected jfw 19-Sept-2005
        Zu      Zw      m*V*cos(alpha)+Zq   -m*g*sin(theta) % corrected jfw 19-Sept-2005
        Mu      Mw      Mq                  0
        0       0       1                   0];
b =[    Xde;    Zde;    Mde;                0];  

A   =   inv(M)*a;
B   =   inv(M)*b;
    if isnan(A) % check for errors
        %set(fdacad,'Pointer','custom');
        errordlg('Aircraft data is incomplete or invalid.','Invalid Data','modal'),        
        clc
        return
    end

[Acol,Arow]=size(A);
C   =   eye(Acol);
[Cr,Cc]=size(C);
D   =   zeros(Cr,1);
SYSac = ss(A,B,C,D, 'inputname',{'Elevator'},...
                    'outputname',{'u' 'w' 'q' '\theta'});
[NUM,DEN]=ss2tf(A,B,C,D);
Bbas=B;,Abas=A;

% augment the C (output) matrix to include Az Gamma h alpha
%       u       w       q                   theta
Caug=[ A(2,1)  A(2,2)   (A(2,3)-V*cos(alpha)) (A(2,4)+g*sin(theta))% az - correction MVC
        0       1/V     0                   0    % alpha
        0       -1/V    0                   1    % gamma
        0       -1      0                   V  ];% NOT h - should be dh MVC
[Arow, Acol] = size(A);
C=[C ; Caug zeros(4, Acol-4)];    
[CaugR, CaugC] = size(Caug);
[DR, DC] = size(D);
D=[D;B(2);zeros(CaugR-1,DC)];% Corrected MVC
SYSaug = ss(A,B,C,D);
[NUM,DEN]=ss2tf(A,B,C,D);
Cbas=C;,Dbas=D;

%   Replace numerator coefficients < 10^-8 with zeros
index=find(abs(NUM)<10e-8);
NUM(index)=0;

[Wn z]  =   damp(DEN);
roots   =   eig(A);

if ~isappdata(0,'ATRANS') %The basic aircraft window is active
set(handles.Wn,'String',Wn);
set(handles.Z,'String',z);
else
end

if isappdata(0,'ATRANS') % The Stability and Control Window is active
%   retrieve values from GUI
actNUM  =   str2num(get(handles.actNUM, 'String'));
actDEN  =   str2num(get(handles.actDEN, 'String'));
Ku      =   get(handles.Ku, 'Value');
Kw      =   get(handles.Kw, 'Value');
Kq      =   get(handles.Kq, 'Value');
Ktheta  =   get(handles.Ktheta, 'Value');
%   Actuator Model
SYSact  =   tf([actNUM], [actDEN]);
%   Feedback Models
SYSku = tf([Ku],[1]);
SYSkw = tf([Kw],[1]);
SYSkq = tf([Kq],[1]);
SYSktheta = tf([Ktheta],[1]);    

%Activate WHEN Handling qualities window is opened
%T2      =   str2double(get(handles.T2, 'String'));
%T2dash  =   str2double(get(handles.T2dash, 'String'));
%Ks      =   str2double(get(handles.Ks, 'String'))   ;
% feelNUM =   str2num(get(handles.feelNUM, 'String'));
% feelDEN =   str2num(get(handles.feelDEN, 'String'));
%   Pre-filter model 
PrePole = 0;
% if T2dash == 0 
%     SYSpre = tf(1, 1);
% elseif T2 == 0
%     SYSpre = tf(1, 1);
% else
%     SYSpre = tf([1 1/T2dash],[1 1/T2]);
%     PrePole = 1;
% end
% %   Feelsystem and Ks Model
% SYSfeel = tf(Ks*feelNUM,feelDEN);  
feelNUM=[];,feelDEN=[]; %DEACTIVATE in handling qualities

%APPEND all system model blocks
 SYS = append(SYSac, SYSact, SYSku, SYSkw, SYSkq, SYSktheta, 1);
 
%CONNECT all system model blocks
 Q   =   [   1   5   0   0   0  0
             2  -6  -7  -8  -9  10
             3   1   0   0   0  0
             4   2   0   0   0  0
             5   3   0   0   0  0
             6   4   0   0   0  0];
 inputs = [7];
 outputs = [1 2 3 4];
 SYSTEM = connect(SYS,Q,inputs,outputs);
 [A,B,C,D] = ssdata(SYSTEM);

[actr,actcol]=size(actDEN);
% augment the C (output) matrix to include Az Gamma h alpha
if actcol==1 % Zero order actuator unity gain
%       u       w             q             theta
Caug=[ A(2,1)  A(2,2)   A(2,3)-V*cos(alpha) A(2,4) % az
        0       1/V           0               0    % alpha
        0       -1/V          0               1    % gamma
        0       -1            0               V  ];% h
[Arow, Acol] = size(A);
C=[C ; Caug zeros(4, Acol-4)];    
[CaugR, CaugC] = size(Caug);
[DR, DC] = size(D);
D=[D;zeros(CaugR,DC)];
SYSaug = ss(A,B,C,D);
[NUM,DEN]=ss2tf(A,B,C,D);
elseif actcol==2 % First order actuator
Caug=[ A(2,1)  A(2,2)  A(2,3)-V*cos(alpha)    A(2,4)   A(2,5) % az
        0       1/V          0                  0       0     % alpha
        0       -1/V         0                  1       0     % gamma
        0       -1           0                  V       0  ]; % h
[Arow, Acol] = size(A);
C=[C ; Caug ];    
[CaugR, CaugC] = size(Caug);
[DR, DC] = size(D);
D=[D;B(2);zeros(CaugR-1,DC)];
SYSaug = ss(A,B,C,D);
[NUM,DEN]=ss2tf(A,B,C,D);
elseif actcol==3 % Second order actuator
Caug=[ A(2,1)  A(2,2)  A(2,3)-V*cos(alpha)    A(2,4)   A(2,5)  A(2,6) % az - correction MVC
        0       1/V          0                  0       0        0    % alpha
        0       -1/V         0                  1       0        0    % gamma
        0       -1           0                  V       0        0]; % h
[Arow, Acol] = size(A);
C=[C ; Caug ];    
[CaugR, CaugC] = size(Caug);
[DR, DC] = size(D);
D=[D;B(2);zeros(CaugR-1,DC)];
SYSaug = ss(A,B,C,D);
[NUM,DEN]=ss2tf(A,B,C,D);
end

%   remove any numerator coefficients < 10^-8 resulting from computation errors
index=find(abs(NUM)<10^-8);
NUM(index)=0;

[Wn z]  =   damp(DEN);
roots   =   eig(A);

set(handles.Z,'String',z);
set(handles.Wn,'String',Wn);
if length(z) == 4
    set(handles.LongPolePlacement,'Enable','on')
else
    set(handles.LongPolePlacement,'Enable','off')
end



% output the pole charateristics to the GUI (pole placement)
% find position of real & complex pole positions within the z vector
countreal=0;
countcomp=0;
RealPole(1)=0;
CompPole(1)=0;
%keyboard
for temp = 1:(length(z)- length(actDEN) - length(feelDEN) + 1)
    if abs(z(temp)) == 1; 
        countreal = countreal + 1;
        RealPole(countreal) = temp; 
    else
        countcomp = countcomp +1;
        CompPole(countcomp) = temp;
    end;
end;
%countreal = countreal - PrePole; %Activate in handling qualities
NumPoles = length (Wn);
%WoPoles = NumPoles - length(actDEN) - length(feelDEN) - PrePole - 2; % number of washout poles
PolePos = countreal;% - WoPoles ;
switch PolePos
%   Assume that actuator roots will remain higher that other system roots    
    case 0 % 2 complex pair roots
        set(handles.Wp, 'Value', Wn(CompPole(1)),...
                        'ForegroundColor', [0 0 0],...
                        'String', round(Wn(CompPole(1))*10000)/10000);
        set(handles.Zp, 'Value', z(CompPole(2)),...
                        'ForegroundColor', [0 0 0],...
                        'String', round(z(CompPole(2))*10000)/10000);
        set(handles.Ws, 'Value', Wn(CompPole(3)),...
                        'ForegroundColor', [0 0 0],...
                        'String', round(Wn(CompPole(3))*10000)/10000);
        set(handles.Zs, 'Value', z(CompPole(4)),...
                        'ForegroundColor', [0 0 0],...
                        'String', round(z(CompPole(4))*10000)/10000);
    case 2    % 1 complex pair and 2 real roots
        if RealPole(1) == 3     % Short period poles are real
            set(handles.Ws, 'Value', Wn(RealPole(1))*z(RealPole(1)),...
                            'ForegroundColor', [0 0 1],...
                            'String', round(Wn(RealPole(1))*z(RealPole(1))*10000)/10000);
            set(handles.Zs, 'Value', Wn(RealPole(2))*z(RealPole(2)),...
                            'ForegroundColor', [0 0 1],...
                            'String', round(Wn(RealPole(2))*z(RealPole(2))*10000)/10000);
            set(handles.Wp, 'Value', Wn(CompPole(1)),...
                            'ForegroundColor', [0 0 0],...
                            'String', round(Wn(CompPole(1))*10000)/10000);
            set(handles.Zp, 'Value', z(CompPole(2)),...
                            'ForegroundColor', [0 0 0],...
                            'String', round(z(CompPole(2))*10000)/10000);
        else                    % Phugoid poles are real
            set(handles.Wp, 'Value', Wn(RealPole(1))*z(RealPole(1)),...
                            'ForegroundColor', [0 0 1],...
                            'String', round(Wn(RealPole(1))*z(RealPole(1))*10000)/10000);
            set(handles.Zp, 'Value', Wn(RealPole(2))*z(RealPole(2)),...
                            'ForegroundColor', [0 0 1],...
                            'String', round(Wn(RealPole(2))*z(RealPole(2))*10000)/10000);
            set(handles.Ws, 'Value', Wn(CompPole(1)),...
                            'ForegroundColor', [0 0 0],...
                            'String', round(Wn(CompPole(1))*10000)/10000);
            set(handles.Zs, 'Value', z(CompPole(2)),...
                            'ForegroundColor', [0 0 0],...
                            'String', round(z(CompPole(2))*10000)/10000);
        end
    case 4  % 4 real roots
        set(handles.Wp, 'Value', Wn(RealPole(1))*z(RealPole(1)),...
                        'ForegroundColor', [0 0 1],...
                        'String', round(Wn(RealPole(1))*z(RealPole(1))*10000)/10000);
        set(handles.Zp, 'Value', Wn(RealPole(2))*z(RealPole(2)),...
                        'ForegroundColor', [0 0 1],...
                        'String', round(Wn(RealPole(2))*z(RealPole(2))*10000)/10000);
        set(handles.Ws, 'Value', Wn(RealPole(3))*z(RealPole(3)),...
                        'ForegroundColor', [0 0 1],...
                        'String', round(Wn(RealPole(3))*z(RealPole(3))*10000)/10000);
        set(handles.Zs, 'Value', Wn(RealPole(4))*z(RealPole(4)),...
                        'ForegroundColor', [0 0 1],...
                        'String', round(Wn(RealPole(4))*z(RealPole(4))*10000)/10000);    
end
end  %of 'if isapp(0,'ATRANS')'
set(handles.u_lon_ch,'enable','on'); % MVC resets  plot selection 
%for u to on after reduced order analysis
return
