function [NUM,DEN, A, B, C, D] = ShortSolve(handles);
% This function Solves the Reduced Order Longitudinal equations of motion.
% It is used only in the Basic aircraft screen to check the short period
% dynamics of the aircraft. 
% Updates the GUI with the SPPO System Pole Characteristics
% Updates the GUI with the SPPO frequency and damping ratio
% Originally created by Rees 2003
% Modified by Konstantinos Siliverdis 20-Aug-2004
% Modified by Michael Cook Feb 2013

A = geta(handles);

% set(handles.Wp,'Enable','off')
% set(handles.Zp,'Enable','off')

if A(27)==1
Adim=A;
elseif A(27)== 2
Adim=norm2dal(A);
elseif A(27)==3
Adim=dless2dal(A);
end;

m=Adim(6);
g=Adim(11);
V=Adim(5);
Iy=Adim(7);
Xu=Adim(12);
Xw=Adim(13);
Xdw=Adim(14);
Xq=Adim(15);
Xde=Adim(16);
Zu=Adim(17);
Zw=Adim(18);
Zdw=Adim(19);
Zq=Adim(20);
Zde=Adim(21);
Mu=Adim(22);
Mw=Adim(23);
Mdw=Adim(24);
Mq=Adim(25);
Mde=Adim(26);
theta=(A(3)+A(4))*pi/180;
alpha=A(4)*pi/180;

%  Define Aircraft Model
M=[(m-Zdw),0,0;-Mdw,Iy,0;0,0,1];% Mass matrix

a=[Zw,(m*V*cos(alpha)+Zq),-m*g*sin(theta);Mw, Mq, 0;0,1,0];
b   =   [Zde; Mde; 0];        
A   =   inv(M)*a; % State matrix
B   =   inv(M)*b; % Input matrix
    if isnan(A)
        %set(fdacad,'Pointer','custom');
        errordlg('Aircraft data is incomplete or invalid.','Invalid Data','modal'),        
       %clc
        return
    end
% Basic reduced order aircraft output equation
[Acol,Arow]=size(A);
C   =   eye(Acol);
[Cr,Cc]=size(C);
D   =   zeros(Cr,1);
SYSac = ss(A,B,C,D);

% Augment output equation to include additional variables - az, alpha,
% gamma and dh.
Cro=[C;A(1,1),(A(1,2)-V*cos(alpha)),A(1,3);1/V,0,0;-1/V,0,1;-1,0,V];
Dro=[D;B(1,1);0;0;0];
[NUM,DEN]=ss2tf(A,B,Cro,Dro);% Defines reduced order aircraft model.

%   Set very small coefficients to zero, for coefficients < 10^-8
index=find(abs(NUM)<10e-8);
NUM(index)=0;

SYSw    =tf(NUM(1,:),DEN,'inputname','Ps','outputname','w - Normal velocity perturbation');
SYSq    =tf(NUM(2,:),DEN,'inputname','Ps','outputname','q - Pitch rate');
SYStheta=tf(NUM(3,:),DEN,'inputname','Ps','outputname','\theta - Pitch attitude');
SYSaz   =tf(NUM(4,:),DEN,'inputname','Ps','outputname','Az - Normal acceleration');
SYSalpha=tf(NUM(5,:),DEN,'inputname','Ps','outputname','\alpha - Angle of attack');
SYSgamma=tf(NUM(6,:),DEN,'inputname','Ps','outputname','\gamma - Flight path angle');
SYSh    =tf(NUM(7,:),DEN,'inputname','Ps','outputname','dh - Height rate');

[Wn z]  =   damp(DEN);
%index=find(Wn==0);
%if index==1
   % Wn=Wn(2:end);
    %z=z(2:end);
%elseif index==length(Wn)
   % Wn=Wn(1:end-1);
    %z=z(1:end-1);
%else
    %Wn=[Wn(1:index-1);Wn(index+1:end)];
    %z=[z(1:index-1);z(index+1:end)];
%end

roots   =   eig(A);
set(handles.Z,'String',z);
set(handles.Wn,'String',Wn);
set(handles.u_lon_ch,'enable','off'); % MVC Switches off u plot variable

clc
return