function units(handles,Arg) 

% This module changes the tooltips to reflect the correct derivative units
% based on the derivative format selected. Originally created by Rees
% 2003, modified to prevent the tooltips appear in the opening screen by
% Konstantinos Siliverdis 20-Aug-2004 
switch Arg
    case 'on'
switch get(handles.mode,'String')
    case 'long'
        switch get(handles.DerivativeFormat,'Value')
            case 1 % Dimensional
                set(handles.Xu,     'Tooltip', 'kg/s OR slugs/s')                
                set(handles.Xw,     'Tooltip', 'kg/s OR slugs/s')   
                set(handles.Xdw,    'Tooltip', 'kg OR slugs')
                set(handles.Xq,     'Tooltip', 'kg.m/s OR slug.ft/s')
                set(handles.Xde,    'Tooltip', 'kg.m/s^2/rad OR slug.ft/s^2/rad')
                set(handles.Zu,     'Tooltip', 'kg/s OR slugs/s')                
                set(handles.Zw,     'Tooltip', 'kg/s OR slugs/s')   
                set(handles.Zdw,    'Tooltip', 'kg OR slugs')
                set(handles.Zq,     'Tooltip', 'kg.m/s OR slug.ft/s')
                set(handles.Zde,    'Tooltip', 'kg.m/s^2/rad OR slug.ft/s^2/rad')
                set(handles.Mu,     'Tooltip', 'kg.m/s OR slug.ft/s')                
                set(handles.Mw,     'Tooltip', 'kg.m/s OR slug.ft/s') 
                set(handles.Mdw,    'Tooltip', 'kg.m OR slug.ft')
                set(handles.Mq,     'Tooltip', 'kg.m^2/s OR slug.ft^2/s')
                set(handles.Mde,    'Tooltip', 'kg.m^2/s^2/rad OR slug.ft^2/s^2/rad')              
            case 2 % Normalised
                set(handles.Xu,     'Tooltip', '1/s')                
                set(handles.Xw,     'Tooltip', '1/s')   
                set(handles.Xdw,    'Tooltip', 'no units') 
                set(handles.Xq,     'Tooltip', 'm/s OR ft/s')
                set(handles.Xde,    'Tooltip', 'm/s^2 OR ft/s^2')
                set(handles.Zu,     'Tooltip', '1/s')              
                set(handles.Zw,     'Tooltip', '1/s') 
                set(handles.Zdw,    'Tooltip', 'no units') 
                set(handles.Zq,     'Tooltip', 'm/s OR ft/s')
                set(handles.Zde,    'Tooltip', 'm/s^2 OR ft/s^2')
                set(handles.Mu,     'Tooltip', '1/(m.s) OR 1/(ft.s)')     
                set(handles.Mw,     'Tooltip', '1/(m.s) OR 1/(ft.s)')
                set(handles.Mdw,    'Tooltip', '1/m OR 1/ft')
                set(handles.Mq,     'Tooltip', '1/s')
                set(handles.Mde,    'Tooltip', '1/s^2')                
            case 3 % Dimensionless
                set(handles.Xu,     'Tooltip', 'no units')           
                set(handles.Xw,     'Tooltip', 'no units')
                set(handles.Xdw,    'Tooltip', 'no units')
                set(handles.Xq,     'Tooltip', 'no units')
                set(handles.Xde,    'Tooltip', '1/rad')
                set(handles.Zu,     'Tooltip', 'no units')       
                set(handles.Zw,     'Tooltip', 'no units')
                set(handles.Zdw,    'Tooltip', 'no units')
                set(handles.Zq,     'Tooltip', 'no units')
                set(handles.Zde,    'Tooltip', '1/rad')
                set(handles.Mu,     'Tooltip', 'no units')
                set(handles.Mw,     'Tooltip', 'no units')
                set(handles.Mdw,    'Tooltip', 'no units')
                set(handles.Mq,     'Tooltip', 'no units')
                set(handles.Mde,    'Tooltip', '1/rad')
        end
    case 'lat'
        switch get(handles.DerivativeFormat,'Value')
            case 1 % Dimensional
                set(handles.Yv, 'Tooltip', 'kg/s OR slugs/s')                
                set(handles.Yp, 'Tooltip', 'kg.m/s OR slug.ft/s')   
                set(handles.Yr, 'Tooltip', 'kg.m/s OR slug.ft/s')  
                set(handles.Yda,'Tooltip', 'kg.m/s^2/rad OR slug.ft/s^2/rad')  
                set(handles.Ydr,'Tooltip', 'kg.m/s^2/rad OR slug.ft/s^2/rad') 
                set(handles.Lv, 'Tooltip', 'kg.m/s OR slug.ft/s')                
                set(handles.Lp, 'Tooltip', 'kg.m^2/s OR slug.ft^2/s')   
                set(handles.Lr, 'Tooltip', 'kg.m^2/s OR slug.ft^2/s')   
                set(handles.Lda,'Tooltip', 'kg.m/s^2/rad OR slug.ft/s^2/rad')  
                set(handles.Ldr,'Tooltip', 'kg.m/s^2/rad OR slug.ft/s^2/rad')   
                set(handles.Nv, 'Tooltip', 'kg.m/s OR slug.ft/s')                   
                set(handles.Np, 'Tooltip', 'kg.m^2/s OR slug.ft^2/s')   
                set(handles.Nr, 'Tooltip', 'kg.m^2/s OR slug.ft^2/s')   
                set(handles.Nda,'Tooltip', 'kg.m^2/s^2/rad OR slug.ft^/s^2/rad')   
                set(handles.Ndr,'Tooltip', 'kg.m^2/s^2/rad OR slug.ft^2/s^2/rad')              
            case 2 % Normalised
                set(handles.Yv, 'Tooltip', '1/s')                
                set(handles.Yp, 'Tooltip', 'm/s OR ft/s')   
                set(handles.Yr, 'Tooltip', 'm/s OR ft/s')    
                set(handles.Yda,'Tooltip', 'm/s^2 OR ft/s^2')  
                set(handles.Ydr,'Tooltip', 'm/s^2 OR ft/s^2') 
                set(handles.Lv, 'Tooltip', '1/(m.s) OR 1/(ft.s)')                
                set(handles.Lp, 'Tooltip', '1/s')   
                set(handles.Lr, 'Tooltip', '1/s')   
                set(handles.Lda,'Tooltip', '1/s^2')   
                set(handles.Ldr,'Tooltip', '1/s^2')  
                set(handles.Nv, 'Tooltip', '1/(m.s) OR 1/(ft.s)')                    
                set(handles.Np, 'Tooltip', '1/s')   
                set(handles.Nr, 'Tooltip', '1/s')   
                set(handles.Nda,'Tooltip', '1/s^2')   
                set(handles.Ndr,'Tooltip', '1/s^2')              
            case 3 % Dimensionless
                set(handles.Yv, 'Tooltip', 'no units')                
                set(handles.Yp, 'Tooltip', 'no units')             
                set(handles.Yr, 'Tooltip', 'no units')             
                set(handles.Yda,'Tooltip', '1/rad')                
                set(handles.Ydr,'Tooltip', '1/rad')                
                set(handles.Lv, 'Tooltip', 'no units')                             
                set(handles.Lp, 'Tooltip', 'no units')                
                set(handles.Lr, 'Tooltip', 'no units')                
                set(handles.Lda,'Tooltip', '1/rad') 
                set(handles.Ldr,'Tooltip', '1/rad') 
                set(handles.Nv, 'Tooltip', 'no units')                 
                set(handles.Np, 'Tooltip', 'no units')                
                set(handles.Nr, 'Tooltip', 'no units')                
                set(handles.Nda,'Tooltip', '/rad')     
                set(handles.Ndr,'Tooltip', '/rad')    
        end
end

case 'off'
    switch get(handles.mode,'String')
    case 'long'
        switch get(handles.DerivativeFormat,'Value')
            case 1 % Dimensional
                set(handles.Xu,     'Tooltip', '')                
                set(handles.Xw,     'Tooltip', '')   
                set(handles.Xdw,    'Tooltip', '')
                set(handles.Xq,     'Tooltip', '')
                set(handles.Xde,    'Tooltip', '')
                set(handles.Zu,     'Tooltip', '')                
                set(handles.Zw,     'Tooltip', '')   
                set(handles.Zdw,    'Tooltip', '')
                set(handles.Zq,     'Tooltip', '')
                set(handles.Zde,    'Tooltip', '')
                set(handles.Mu,     'Tooltip', '')                
                set(handles.Mw,     'Tooltip', '') 
                set(handles.Mdw,    'Tooltip', '')
                set(handles.Mq,     'Tooltip', '')
                set(handles.Mde,    'Tooltip', '')              
            case 2 % Normalised
                set(handles.Xu,     'Tooltip', '')                
                set(handles.Xw,     'Tooltip', '')   
                set(handles.Xdw,    'Tooltip', '') 
                set(handles.Xq,     'Tooltip', '')
                set(handles.Xde,    'Tooltip', '')
                set(handles.Zu,     'Tooltip', '')              
                set(handles.Zw,     'Tooltip', '') 
                set(handles.Zdw,    'Tooltip', '') 
                set(handles.Zq,     'Tooltip', '')
                set(handles.Zde,    'Tooltip', '')
                set(handles.Mu,     'Tooltip', '')     
                set(handles.Mw,     'Tooltip', '')
                set(handles.Mdw,    'Tooltip', '')
                set(handles.Mq,     'Tooltip', '')
                set(handles.Mde,    'Tooltip', '')                
            case 3 % Dimensionless
                set(handles.Xu,     'Tooltip', '')           
                set(handles.Xw,     'Tooltip', '')
                set(handles.Xdw,    'Tooltip', '')
                set(handles.Xq,     'Tooltip', '')
                set(handles.Xde,    'Tooltip', '')
                set(handles.Zu,     'Tooltip', '')       
                set(handles.Zw,     'Tooltip', '')
                set(handles.Zdw,    'Tooltip', '')
                set(handles.Zq,     'Tooltip', '')
                set(handles.Zde,    'Tooltip', '')
                set(handles.Mu,     'Tooltip', '')
                set(handles.Mw,     'Tooltip', '')
                set(handles.Mdw,    'Tooltip', '')
                set(handles.Mq,     'Tooltip', '')
                set(handles.Mde,    'Tooltip', '')
        end
    case 'lat'
        switch get(handles.DerivativeFormat,'Value')
            case 1 % Dimensional
                set(handles.Yv, 'Tooltip', '')                
                set(handles.Yp, 'Tooltip', '')   
                set(handles.Yr, 'Tooltip', '')  
                set(handles.Yda,'Tooltip', '')  
                set(handles.Ydr,'Tooltip', '') 
                set(handles.Lv, 'Tooltip', '')                
                set(handles.Lp, 'Tooltip', '')   
                set(handles.Lr, 'Tooltip', '')   
                set(handles.Lda,'Tooltip', '')  
                set(handles.Ldr,'Tooltip', '')   
                set(handles.Nv, 'Tooltip', '')                   
                set(handles.Np, 'Tooltip', '')   
                set(handles.Nr, 'Tooltip', '')   
                set(handles.Nda,'Tooltip', '')   
                set(handles.Ndr,'Tooltip', '')              
            case 2 % Normalised
                set(handles.Yv, 'Tooltip', '')                
                set(handles.Yp, 'Tooltip', '')   
                set(handles.Yr, 'Tooltip', '')    
                set(handles.Yda,'Tooltip', '')  
                set(handles.Ydr,'Tooltip', '') 
                set(handles.Lv, 'Tooltip', '')                
                set(handles.Lp, 'Tooltip', '')   
                set(handles.Lr, 'Tooltip', '')   
                set(handles.Lda,'Tooltip', '')   
                set(handles.Ldr,'Tooltip', '')  
                set(handles.Nv, 'Tooltip', '')                    
                set(handles.Np, 'Tooltip', '')   
                set(handles.Nr, 'Tooltip', '')   
                set(handles.Nda,'Tooltip', '')   
                set(handles.Ndr,'Tooltip', '')              
            case 3 % Dimensionless
                set(handles.Yv, 'Tooltip', '')                
                set(handles.Yp, 'Tooltip', '')             
                set(handles.Yr, 'Tooltip', '')             
                set(handles.Yda,'Tooltip', '')                
                set(handles.Ydr,'Tooltip', '')                
                set(handles.Lv, 'Tooltip', '')                             
                set(handles.Lp, 'Tooltip', '')                
                set(handles.Lr, 'Tooltip', '')                
                set(handles.Lda,'Tooltip', '') 
                set(handles.Ldr,'Tooltip', '') 
                set(handles.Nv, 'Tooltip', '')                 
                set(handles.Np, 'Tooltip', '')                
                set(handles.Nr, 'Tooltip', '')                
                set(handles.Nda,'Tooltip', '')     
                set(handles.Ndr,'Tooltip', '')    
        end
end
    
    
    
end