function Adaln=dal2norm(A)

% Dimensional to Modified Normalised [USA] derivative conversion
% By Konstantinos Siliverdis 20-Aug-2004
% Lateral conversion corrected by M V Cook February 2013
% See Flight Dynamics Principles (3e) - Para 4.4.3

if length(A)==28 %longitudinal
    
Adaln(1:11)=A(1:11);
Adaln(27:28)=A(27:28);
Adaln(12)=A(12)/A(6);   % Xu  / m
Adaln(13)=A(13)/A(6);   % Xw  / m
Adaln(14)=A(14)/A(6);   % Xdw / m
Adaln(15)=A(15)/A(6);   % Xq  / m
Adaln(16)=A(16)/A(6);   % Xde / m
Adaln(17)=A(17)/A(6);   % Zu  / m
Adaln(18)=A(18)/A(6);   % Zw  / m
Adaln(19)=A(19)/A(6);   % Zdw / m
Adaln(20)=A(20)/A(6);   % Zq  / m
Adaln(21)=A(21)/A(6);   % Zde / m
Adaln(22)=A(22)/A(7);   % Mu  / Iy
Adaln(23)=A(23)/A(7);   % Mw  / Iy
Adaln(24)=A(24)/A(7);   % Mdw / Iy
Adaln(25)=A(25)/A(7);   % Mq  / Iy
Adaln(26)=A(26)/A(7);   % Mde / Iy

elseif length(A)==30 %Lateral
% Note, brackets in following expressions are critical to correct computation.

Adaln(1:13)=A(1:13);
Adaln(29:30)=A(29:30);
Adaln(14)=A(14)/A(6);   % Yv / m
Adaln(15)=A(15)/A(6);   % Yp / m
Adaln(16)=A(16)/A(6);   % Yr / m
Adaln(17)=A(17)/(A(6)*A(5));   % Y*da=Yda/ m*V
Adaln(18)=A(18)/(A(6)*A(5));   % Y*dr=Ydr/ m*V

imult=1/(1-((A(9)*A(9))/(A(7)*A(8)))); %(1/(1-Ixz^2/Ix*Iz))
Adaln(19)=((A(19)/A(7))+((A(24)*A(9))/(A(7)*A(8))))*imult*A(5);   %L'beta=(Lv/Ix+(Nv*Ixz)/Ix*Iz)*(1/(1-Ixz^2/Ix*Iz))*V
Adaln(20)=((A(20)/A(7))+((A(25)*A(9))/(A(7)*A(8))))*imult;   % L'p=(Lp/Ix+(Np*Ixz)/Ix*Iz)*(1/(1-Ixz^2/Ix*Iz))
Adaln(21)=((A(21)/A(7))+((A(26)*A(9))/(A(7)*A(8))))*imult;   % L'r=(Lr/Ix+(Nr*Ixz)/Ix*Iz)*(1/(1-Ixz^2/Ix*Iz))
Adaln(22)=((A(22)/A(7))+((A(27)*A(9))/(A(7)*A(8))))*imult;   % L'da=(Lda/Ix+(Nda*Ixz)/Ix*Iz)*(1/(1-Ixz^2/Ix*Iz))
Adaln(23)=((A(23)/A(7))+((A(28)*A(9))/(A(7)*A(8))))*imult;   % L'dr=(Ldr/Ix+(Ndr*Ixz)/Ix*Iz)*(1/(1-Ixz^2/Ix*Iz))

Adaln(24)=((A(24)/A(8))+((A(19)*A(9))/(A(7)*A(8))))*imult*A(5);  %N'beta=(Nv/Iz+(Lv*Ixz)/Ix*Iz)*(1/(1-Ixz^2/Ix*Iz))*V
Adaln(25)=((A(25)/A(8))+((A(20)*A(9))/(A(7)*A(8))))*imult;  % N'p=(Np/Iz+(Lp*Ixz)/Ix*Iz)*(1/(1-Ixz^2/Ix*Iz))
Adaln(26)=((A(26)/A(8))+((A(21)*A(9))/(A(7)*A(8))))*imult;  % N'r=(Nr/Iz+(Lr*Ixz)/Ix*Iz)*(1/(1-Ixz^2/Ix*Iz))
Adaln(27)=((A(27)/A(8))+((A(22)*A(9))/(A(7)*A(8))))*imult;  % N'da=(Nda/Iz+(Lda*Ixz)/Ix*Iz)*(1/(1-Ixz^2/Ix*Iz))
Adaln(28)=((A(28)/A(8))+((A(23)*A(9))/(A(7)*A(8))))*imult;  % N'dr=(Ndr/Iz+(Ldr*Ixz)/Ix*Iz)*(1/(1-Ixz^2/Ix*Iz))

else
    msgbox('Data is incomplete or invalid. Please check for empty fields','Error in input data','error','modal')
end
