function export2workspace(handles)

% According to the design stage, this routine exports
% a number of variables in the workspace for offline analysis
% By Konstantinos Siliverdis 20-Aug-2004 


if ~isappdata(0,'ATRANS') % Basic Aircraft Screen
    Atemp=geta(handles);
elseif isappdata(0,'ATRANS') % Stability and Control Screen
    Atemp=getappdata(0,'ATRANS');
end


switch get(handles.mode,'string')
    case 'long'
        if ~isappdata(0,'ATRANS')
        switch get(handles.ModelOrder,'value')
            case 1 %Full Order
        [NUM,DEN,A,B,C,D] = Longsolve (handles);
        assignin('base','NUM',NUM)
        assignin('base','DEN',DEN)
            case 2 %Reduced Order
        [NUM,DEN,A,B,C,D] = Shortsolve (handles);
        assignin('base','NUM',NUM)
        assignin('base','DEN',DEN)
        end
        elseif isappdata(0,'ATRANS')
        [NUM,DEN,A,B,C,D] = Longsolve (handles);
        assignin('base','NUM',NUM)
        assignin('base','DEN',DEN)
        end
        
        assignin('base','M',Atemp(1))
        assignin('base','H',Atemp(2))
        assignin('base','gamma',Atemp(3))
        assignin('base','alpha',Atemp(4))
        assignin('base','V',Atemp(5))
        assignin('base','mass',Atemp(6))
        assignin('base','Iy',Atemp(7))
        assignin('base','rho',Atemp(8))
        assignin('base','S',Atemp(9))
        assignin('base','c',Atemp(10))
        assignin('base','g',Atemp(11))
        assignin('base','Xu',Atemp(12))
        assignin('base','Xw',Atemp(13))
        assignin('base','Xdw',Atemp(14))
        assignin('base','Xq',Atemp(15))
        assignin('base','Xde',Atemp(16))
        assignin('base','Zu',Atemp(17))
        assignin('base','Zw',Atemp(18))
        assignin('base','Zdw',Atemp(19))
        assignin('base','Zq',Atemp(20))
        assignin('base','Zde',Atemp(21))
        assignin('base','Mu',Atemp(22))
        assignin('base','Mw',Atemp(23))
        assignin('base','Mdw',Atemp(24))
        assignin('base','Mq',Atemp(25))
        assignin('base','Mde',Atemp(26))
        switch Atemp(27)
            case 1
                assignin('base','DerivForm','Dimensional')
            case 2
                assignin('base','DerivForm','Normalised')
            case 3
                assignin('base','DerivForm','Dimensionless')
        end
        switch Atemp(28)
            case 1
                assignin('base','Axes','Wind')
            case 2
                assignin('base','Axes','Body')
        end
               
                          
    case 'lat'
        [NUMA, NUMR, DENA, A,B,C,D]=latsolve(handles);
        assignin('base','NUMA',NUMA)
        assignin('base','DENA',DENA)
        assignin('base','NUMR',NUMR)
        assignin('base','DENR',DENA)
        
        assignin('base','M',Atemp(1))
        assignin('base','H',Atemp(2))
        assignin('base','gamma',Atemp(3))
        assignin('base','alpha',Atemp(4))
        assignin('base','V',Atemp(5))
        assignin('base','mass',Atemp(6))
        assignin('base','Ix',Atemp(7))
        assignin('base','Iz',Atemp(8))
        assignin('base','Ixy',Atemp(9))
        assignin('base','rho',Atemp(10))
        assignin('base','S',Atemp(11))
        assignin('base','b',Atemp(12))
        assignin('base','g',Atemp(13))
        assignin('base','Yv',Atemp(14))
        assignin('base','Yp',Atemp(15))
        assignin('base','Yr',Atemp(16))
        assignin('base','Yda',Atemp(17))
        assignin('base','Ydr',Atemp(18))
        assignin('base','Lv',Atemp(19))
        assignin('base','Lp',Atemp(20))
        assignin('base','Lr',Atemp(21))
        assignin('base','Lda',Atemp(22))
        assignin('base','Ldr',Atemp(23))
        assignin('base','Nv',Atemp(24))
        assignin('base','Np',Atemp(25))
        assignin('base','Nr',Atemp(26))
        assignin('base','Nda',Atemp(27))
        assignin('base','Ndr',Atemp(28))
        switch Atemp(29)
            case 1
                assignin('base','DerivForm','Dimensional')
            case 2
                assignin('base','DerivForm','Normalised')
            case 3
                assignin('base','DerivForm','Dimensionless')
        end
        switch Atemp(30)
            case 1
                assignin('base','Axes','Wind')
            case 2
                assignin('base','Axes','Body')
        end
        
        
end
assignin('base','A',A)
assignin('base','B',B)
assignin('base','C',C)
assignin('base','D',D)
